Class: Google::Apis::OndemandscanningV1::BaseImage
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::BaseImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
BaseImage describes a base image of a container image.
Instance Attribute Summary collapse
-
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
-
#name ⇒ String
The name of the base image.
-
#registry ⇒ String
The registry in which the base image is from.
-
#repository ⇒ String
The repository name in which the base image is from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BaseImage
constructor
A new instance of BaseImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BaseImage
Returns a new instance of BaseImage.
335 336 337 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 335 def initialize(**args) update!(**args) end |
Instance Attribute Details
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
Corresponds to the JSON property layerCount
318 319 320 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 318 def layer_count @layer_count end |
#name ⇒ String
The name of the base image.
Corresponds to the JSON property name
323 324 325 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 323 def name @name end |
#registry ⇒ String
The registry in which the base image is from.
Corresponds to the JSON property registry
328 329 330 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 328 def registry @registry end |
#repository ⇒ String
The repository name in which the base image is from.
Corresponds to the JSON property repository
333 334 335 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 333 def repository @repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
340 341 342 343 344 345 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 340 def update!(**args) @layer_count = args[:layer_count] if args.key?(:layer_count) @name = args[:name] if args.key?(:name) @registry = args[:registry] if args.key?(:registry) @repository = args[:repository] if args.key?(:repository) end |