Class: Google::Apis::OndemandscanningV1::BuildOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Details of a build occurrence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BuildOccurrence

Returns a new instance of BuildOccurrence.



483
484
485
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 483

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#in_toto_slsa_provenance_v1Google::Apis::OndemandscanningV1::InTotoSlsaProvenanceV1

In-Toto Slsa Provenance V1 represents a slsa provenance meeting the slsa spec, wrapped in an in-toto statement. This allows for direct jsonification of a to- spec in-toto slsa statement with a to-spec slsa provenance. Corresponds to the JSON property inTotoSlsaProvenanceV1



450
451
452
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 450

def in_toto_slsa_provenance_v1
  @in_toto_slsa_provenance_v1
end

#intoto_provenanceGoogle::Apis::OndemandscanningV1::InTotoProvenance

Deprecated. See InTotoStatement for the replacement. In-toto Provenance representation as defined in spec. Corresponds to the JSON property intotoProvenance



456
457
458
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 456

def intoto_provenance
  @intoto_provenance
end

#intoto_statementGoogle::Apis::OndemandscanningV1::InTotoStatement

Spec defined at https://github.com/in-toto/attestation/tree/main/spec# statement The serialized InTotoStatement will be stored as Envelope.payload. Envelope.payloadType is always "application/vnd.in-toto+json". Corresponds to the JSON property intotoStatement



463
464
465
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 463

def intoto_statement
  @intoto_statement
end

#provenanceGoogle::Apis::OndemandscanningV1::BuildProvenance

Provenance of a build. Contains all information needed to verify the full details about the build from source to completion. Corresponds to the JSON property provenance



469
470
471
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 469

def provenance
  @provenance
end

#provenance_bytesString

Serialized JSON representation of the provenance, used in generating the build signature in the corresponding build note. After verifying the signature, provenance_bytes can be unmarshalled and compared to the provenance to confirm that it is unchanged. A base64-encoded string representation of the provenance bytes is used for the signature in order to interoperate with openssl which expects this format for signature verification. The serialized form is captured both to avoid ambiguity in how the provenance is marshalled to json as well to prevent incompatibilities with future changes. Corresponds to the JSON property provenanceBytes

Returns:

  • (String)


481
482
483
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 481

def provenance_bytes
  @provenance_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



488
489
490
491
492
493
494
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 488

def update!(**args)
  @in_toto_slsa_provenance_v1 = args[:in_toto_slsa_provenance_v1] if args.key?(:in_toto_slsa_provenance_v1)
  @intoto_provenance = args[:intoto_provenance] if args.key?(:intoto_provenance)
  @intoto_statement = args[:intoto_statement] if args.key?(:intoto_statement)
  @provenance = args[:provenance] if args.key?(:provenance)
  @provenance_bytes = args[:provenance_bytes] if args.key?(:provenance_bytes)
end