Class: Google::Apis::OndemandscanningV1::BuildProvenance
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::BuildProvenance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Provenance of a build. Contains all information needed to verify the full details about the build from source to completion.
Instance Attribute Summary collapse
-
#build_options ⇒ Hash<String,String>
Special options applied to this build.
-
#builder_version ⇒ String
Version string of the builder at the time this build was executed.
-
#built_artifacts ⇒ Array<Google::Apis::OndemandscanningV1::Artifact>
Output of the build.
-
#commands ⇒ Array<Google::Apis::OndemandscanningV1::Command>
Commands requested by the build.
-
#create_time ⇒ String
Time at which the build was created.
-
#creator ⇒ String
E-mail address of the user who initiated this build.
-
#end_time ⇒ String
Time at which execution of the build was finished.
-
#id ⇒ String
Required.
-
#logs_uri ⇒ String
URI where any logs for this provenance were written.
-
#project_id ⇒ String
ID of the project.
-
#source_provenance ⇒ Google::Apis::OndemandscanningV1::Source
Source describes the location of the source used for the build.
-
#start_time ⇒ String
Time at which execution of the build was started.
-
#trigger_id ⇒ String
Trigger identifier if the build was triggered automatically; empty if not.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BuildProvenance
constructor
A new instance of BuildProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BuildProvenance
Returns a new instance of BuildProvenance.
539 540 541 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 539 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build_options ⇒ Hash<String,String>
Special options applied to this build. This is a catch-all field where build
providers can enter any desired additional details.
Corresponds to the JSON property buildOptions
475 476 477 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 475 def @build_options end |
#builder_version ⇒ String
Version string of the builder at the time this build was executed.
Corresponds to the JSON property builderVersion
480 481 482 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 480 def builder_version @builder_version end |
#built_artifacts ⇒ Array<Google::Apis::OndemandscanningV1::Artifact>
Output of the build.
Corresponds to the JSON property builtArtifacts
485 486 487 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 485 def built_artifacts @built_artifacts end |
#commands ⇒ Array<Google::Apis::OndemandscanningV1::Command>
Commands requested by the build.
Corresponds to the JSON property commands
490 491 492 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 490 def commands @commands end |
#create_time ⇒ String
Time at which the build was created.
Corresponds to the JSON property createTime
495 496 497 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 495 def create_time @create_time end |
#creator ⇒ String
E-mail address of the user who initiated this build. Note that this was the
user's e-mail address at the time the build was initiated; this address may
not represent the same end-user for all time.
Corresponds to the JSON property creator
502 503 504 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 502 def creator @creator end |
#end_time ⇒ String
Time at which execution of the build was finished.
Corresponds to the JSON property endTime
507 508 509 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 507 def end_time @end_time end |
#id ⇒ String
Required. Unique identifier of the build.
Corresponds to the JSON property id
512 513 514 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 512 def id @id end |
#logs_uri ⇒ String
URI where any logs for this provenance were written.
Corresponds to the JSON property logsUri
517 518 519 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 517 def logs_uri @logs_uri end |
#project_id ⇒ String
ID of the project.
Corresponds to the JSON property projectId
522 523 524 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 522 def project_id @project_id end |
#source_provenance ⇒ Google::Apis::OndemandscanningV1::Source
Source describes the location of the source used for the build.
Corresponds to the JSON property sourceProvenance
527 528 529 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 527 def source_provenance @source_provenance end |
#start_time ⇒ String
Time at which execution of the build was started.
Corresponds to the JSON property startTime
532 533 534 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 532 def start_time @start_time end |
#trigger_id ⇒ String
Trigger identifier if the build was triggered automatically; empty if not.
Corresponds to the JSON property triggerId
537 538 539 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 537 def trigger_id @trigger_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 544 def update!(**args) @build_options = args[:build_options] if args.key?(:build_options) @builder_version = args[:builder_version] if args.key?(:builder_version) @built_artifacts = args[:built_artifacts] if args.key?(:built_artifacts) @commands = args[:commands] if args.key?(:commands) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @end_time = args[:end_time] if args.key?(:end_time) @id = args[:id] if args.key?(:id) @logs_uri = args[:logs_uri] if args.key?(:logs_uri) @project_id = args[:project_id] if args.key?(:project_id) @source_provenance = args[:source_provenance] if args.key?(:source_provenance) @start_time = args[:start_time] if args.key?(:start_time) @trigger_id = args[:trigger_id] if args.key?(:trigger_id) end |