Class: Google::Apis::OndemandscanningV1::CisaKnownExploitedVulnerabilities
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::CisaKnownExploitedVulnerabilities
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Instance Attribute Summary collapse
-
#known_ransomware_campaign_use ⇒ String
Whether the vulnerability is known to have been leveraged as part of a ransomware campaign.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CisaKnownExploitedVulnerabilities
constructor
A new instance of CisaKnownExploitedVulnerabilities.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CisaKnownExploitedVulnerabilities
Returns a new instance of CisaKnownExploitedVulnerabilities.
590 591 592 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#known_ransomware_campaign_use ⇒ String
Whether the vulnerability is known to have been leveraged as part of a
ransomware campaign.
Corresponds to the JSON property knownRansomwareCampaignUse
588 589 590 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 588 def known_ransomware_campaign_use @known_ransomware_campaign_use end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
595 596 597 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 595 def update!(**args) @known_ransomware_campaign_use = args[:known_ransomware_campaign_use] if args.key?(:known_ransomware_campaign_use) end |