Class: Google::Apis::OndemandscanningV1::Command

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Command describes a step performed as part of the build pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Command

Returns a new instance of Command.



814
815
816
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 814

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

Command-line arguments used when executing this command. Corresponds to the JSON property args

Returns:

  • (Array<String>)


784
785
786
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 784

def args
  @args
end

#dirString

Working directory (relative to project source root) used when running this command. Corresponds to the JSON property dir

Returns:

  • (String)


790
791
792
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 790

def dir
  @dir
end

#envArray<String>

Environment variables set before running this command. Corresponds to the JSON property env

Returns:

  • (Array<String>)


795
796
797
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 795

def env
  @env
end

#idString

Optional unique identifier for this command, used in wait_for to reference this command as a dependency. Corresponds to the JSON property id

Returns:

  • (String)


801
802
803
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 801

def id
  @id
end

#nameString

Required. Name of the command, as presented on the command line, or if the command is packaged as a Docker container, as presented to docker pull. Corresponds to the JSON property name

Returns:

  • (String)


807
808
809
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 807

def name
  @name
end

#wait_forArray<String>

The ID(s) of the command(s) that this command depends on. Corresponds to the JSON property waitFor

Returns:

  • (Array<String>)


812
813
814
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 812

def wait_for
  @wait_for
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



819
820
821
822
823
824
825
826
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 819

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @dir = args[:dir] if args.key?(:dir)
  @env = args[:env] if args.key?(:env)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @wait_for = args[:wait_for] if args.key?(:wait_for)
end