Class: Google::Apis::OndemandscanningV1::ComplianceOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ComplianceOccurrence

Returns a new instance of ComplianceOccurrence.



856
857
858
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 856

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#non_compliance_reasonString

Corresponds to the JSON property nonComplianceReason

Returns:

  • (String)


843
844
845
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 843

def non_compliance_reason
  @non_compliance_reason
end

#non_compliant_filesArray<Google::Apis::OndemandscanningV1::NonCompliantFile>

Corresponds to the JSON property nonCompliantFiles



848
849
850
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 848

def non_compliant_files
  @non_compliant_files
end

#versionGoogle::Apis::OndemandscanningV1::ComplianceVersion

Describes the CIS benchmark version that is applicable to a given OS and os version. Corresponds to the JSON property version



854
855
856
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 854

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



861
862
863
864
865
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 861

def update!(**args)
  @non_compliance_reason = args[:non_compliance_reason] if args.key?(:non_compliance_reason)
  @non_compliant_files = args[:non_compliant_files] if args.key?(:non_compliant_files)
  @version = args[:version] if args.key?(:version)
end