Class: Google::Apis::OndemandscanningV1::Cvss
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::Cvss
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version.
Instance Attribute Summary collapse
-
#attack_complexity ⇒ String
Attack Complexity (AC).
-
#attack_requirements ⇒ String
Attack Requirements (AT).
-
#attack_vector ⇒ String
Attack Vector (AV).
-
#authentication ⇒ String
Authentication (Au).
-
#availability_impact ⇒ String
Availability Impact (A).
-
#base_score ⇒ Float
The base score is a function of the base metric scores.
-
#confidentiality_impact ⇒ String
Confidentiality Impact (C).
-
#exploit_maturity ⇒ String
Exploit Maturity (E).
-
#exploitability_score ⇒ Float
Corresponds to the JSON property
exploitabilityScore. -
#impact_score ⇒ Float
Corresponds to the JSON property
impactScore. -
#integrity_impact ⇒ String
Integrity Impact (I).
-
#privileges_required ⇒ String
Privileges Required (PR).
-
#scope ⇒ String
Scope (S).
-
#subsequent_system_availability_impact ⇒ String
Subsequent System Availability Impact (SA).
-
#subsequent_system_confidentiality_impact ⇒ String
Subsequent System Confidentiality Impact (SC).
-
#subsequent_system_integrity_impact ⇒ String
Subsequent System Integrity Impact (SI).
-
#user_interaction ⇒ String
User Interaction (UI).
-
#vulnerable_system_availability_impact ⇒ String
Vulnerable System Availability Impact (VA).
-
#vulnerable_system_confidentiality_impact ⇒ String
Vulnerable System Confidentiality Impact (VC).
-
#vulnerable_system_integrity_impact ⇒ String
Vulnerable System Integrity Impact (VI).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Cvss
constructor
A new instance of Cvss.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Cvss
Returns a new instance of Cvss.
750 751 752 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attack_complexity ⇒ String
Attack Complexity (AC). Defined in CVSS v2, v3, v4.
Corresponds to the JSON property attackComplexity
653 654 655 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 653 def attack_complexity @attack_complexity end |
#attack_requirements ⇒ String
Attack Requirements (AT). Defined in CVSS v4.
Corresponds to the JSON property attackRequirements
658 659 660 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 658 def attack_requirements @attack_requirements end |
#attack_vector ⇒ String
Attack Vector (AV). Defined in CVSS v2, v3, v4.
Corresponds to the JSON property attackVector
663 664 665 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 663 def attack_vector @attack_vector end |
#authentication ⇒ String
Authentication (Au). Defined in CVSS v2.
Corresponds to the JSON property authentication
668 669 670 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 668 def authentication @authentication end |
#availability_impact ⇒ String
Availability Impact (A). Defined in CVSS v2, v3.
Corresponds to the JSON property availabilityImpact
673 674 675 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 673 def availability_impact @availability_impact end |
#base_score ⇒ Float
The base score is a function of the base metric scores.
Corresponds to the JSON property baseScore
678 679 680 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 678 def base_score @base_score end |
#confidentiality_impact ⇒ String
Confidentiality Impact (C). Defined in CVSS v2, v3.
Corresponds to the JSON property confidentialityImpact
683 684 685 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 683 def confidentiality_impact @confidentiality_impact end |
#exploit_maturity ⇒ String
Exploit Maturity (E). Defined in CVSS v4.
Corresponds to the JSON property exploitMaturity
688 689 690 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 688 def exploit_maturity @exploit_maturity end |
#exploitability_score ⇒ Float
Corresponds to the JSON property exploitabilityScore
693 694 695 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 693 def exploitability_score @exploitability_score end |
#impact_score ⇒ Float
Corresponds to the JSON property impactScore
698 699 700 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 698 def impact_score @impact_score end |
#integrity_impact ⇒ String
Integrity Impact (I). Defined in CVSS v2, v3.
Corresponds to the JSON property integrityImpact
703 704 705 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 703 def integrity_impact @integrity_impact end |
#privileges_required ⇒ String
Privileges Required (PR). Defined in CVSS v3, v4.
Corresponds to the JSON property privilegesRequired
708 709 710 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 708 def privileges_required @privileges_required end |
#scope ⇒ String
Scope (S). Defined in CVSS v3.
Corresponds to the JSON property scope
713 714 715 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 713 def scope @scope end |
#subsequent_system_availability_impact ⇒ String
Subsequent System Availability Impact (SA). Defined in CVSS v4.
Corresponds to the JSON property subsequentSystemAvailabilityImpact
718 719 720 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 718 def subsequent_system_availability_impact @subsequent_system_availability_impact end |
#subsequent_system_confidentiality_impact ⇒ String
Subsequent System Confidentiality Impact (SC). Defined in CVSS v4.
Corresponds to the JSON property subsequentSystemConfidentialityImpact
723 724 725 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 723 def subsequent_system_confidentiality_impact @subsequent_system_confidentiality_impact end |
#subsequent_system_integrity_impact ⇒ String
Subsequent System Integrity Impact (SI). Defined in CVSS v4.
Corresponds to the JSON property subsequentSystemIntegrityImpact
728 729 730 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 728 def subsequent_system_integrity_impact @subsequent_system_integrity_impact end |
#user_interaction ⇒ String
User Interaction (UI). Defined in CVSS v3, v4.
Corresponds to the JSON property userInteraction
733 734 735 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 733 def user_interaction @user_interaction end |
#vulnerable_system_availability_impact ⇒ String
Vulnerable System Availability Impact (VA). Defined in CVSS v4.
Corresponds to the JSON property vulnerableSystemAvailabilityImpact
738 739 740 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 738 def vulnerable_system_availability_impact @vulnerable_system_availability_impact end |
#vulnerable_system_confidentiality_impact ⇒ String
Vulnerable System Confidentiality Impact (VC). Defined in CVSS v4.
Corresponds to the JSON property vulnerableSystemConfidentialityImpact
743 744 745 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 743 def vulnerable_system_confidentiality_impact @vulnerable_system_confidentiality_impact end |
#vulnerable_system_integrity_impact ⇒ String
Vulnerable System Integrity Impact (VI). Defined in CVSS v4.
Corresponds to the JSON property vulnerableSystemIntegrityImpact
748 749 750 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 748 def vulnerable_system_integrity_impact @vulnerable_system_integrity_impact end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 755 def update!(**args) @attack_complexity = args[:attack_complexity] if args.key?(:attack_complexity) @attack_requirements = args[:attack_requirements] if args.key?(:attack_requirements) @attack_vector = args[:attack_vector] if args.key?(:attack_vector) @authentication = args[:authentication] if args.key?(:authentication) @availability_impact = args[:availability_impact] if args.key?(:availability_impact) @base_score = args[:base_score] if args.key?(:base_score) @confidentiality_impact = args[:confidentiality_impact] if args.key?(:confidentiality_impact) @exploit_maturity = args[:exploit_maturity] if args.key?(:exploit_maturity) @exploitability_score = args[:exploitability_score] if args.key?(:exploitability_score) @impact_score = args[:impact_score] if args.key?(:impact_score) @integrity_impact = args[:integrity_impact] if args.key?(:integrity_impact) @privileges_required = args[:privileges_required] if args.key?(:privileges_required) @scope = args[:scope] if args.key?(:scope) @subsequent_system_availability_impact = args[:subsequent_system_availability_impact] if args.key?(:subsequent_system_availability_impact) @subsequent_system_confidentiality_impact = args[:subsequent_system_confidentiality_impact] if args.key?(:subsequent_system_confidentiality_impact) @subsequent_system_integrity_impact = args[:subsequent_system_integrity_impact] if args.key?(:subsequent_system_integrity_impact) @user_interaction = args[:user_interaction] if args.key?(:user_interaction) @vulnerable_system_availability_impact = args[:vulnerable_system_availability_impact] if args.key?(:vulnerable_system_availability_impact) @vulnerable_system_confidentiality_impact = args[:vulnerable_system_confidentiality_impact] if args.key?(:vulnerable_system_confidentiality_impact) @vulnerable_system_integrity_impact = args[:vulnerable_system_integrity_impact] if args.key?(:vulnerable_system_integrity_impact) end |