Class: Google::Apis::OndemandscanningV1::DiscoveryOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Provides information about the analysis status of a discovered resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveryOccurrence

Returns a new instance of DiscoveryOccurrence.



1145
1146
1147
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_completedGoogle::Apis::OndemandscanningV1::AnalysisCompleted

Indicates which analysis completed successfully. Multiple types of analysis can be performed on a single resource. Corresponds to the JSON property analysisCompleted



1086
1087
1088
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1086

def analysis_completed
  @analysis_completed
end

#analysis_errorArray<Google::Apis::OndemandscanningV1::Status>

Indicates any errors encountered during analysis of a resource. There could be 0 or more of these errors. Corresponds to the JSON property analysisError



1092
1093
1094
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1092

def analysis_error
  @analysis_error
end

#analysis_statusString

The status of discovery for the resource. Corresponds to the JSON property analysisStatus

Returns:

  • (String)


1097
1098
1099
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1097

def analysis_status
  @analysis_status
end

#analysis_status_errorGoogle::Apis::OndemandscanningV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property analysisStatusError



1107
1108
1109
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1107

def analysis_status_error
  @analysis_status_error
end

#archive_timeString

Output only. The time occurrences related to this discovery occurrence were archived. Corresponds to the JSON property archiveTime

Returns:

  • (String)


1113
1114
1115
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1113

def archive_time
  @archive_time
end

#continuous_analysisString

Whether the resource is continuously analyzed. Corresponds to the JSON property continuousAnalysis

Returns:

  • (String)


1118
1119
1120
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1118

def continuous_analysis
  @continuous_analysis
end

#cpeString

The CPE of the resource being scanned. Corresponds to the JSON property cpe

Returns:

  • (String)


1123
1124
1125
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1123

def cpe
  @cpe
end

#filesArray<Google::Apis::OndemandscanningV1::File>

Files that make up the resource described by the occurrence. Corresponds to the JSON property files



1128
1129
1130
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1128

def files
  @files
end

#last_scan_timeString

The last time this resource was scanned. Corresponds to the JSON property lastScanTime

Returns:

  • (String)


1133
1134
1135
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1133

def last_scan_time
  @last_scan_time
end

#last_vulnerability_update_timeString

The last time vulnerability scan results changed. Corresponds to the JSON property lastVulnerabilityUpdateTime

Returns:

  • (String)


1138
1139
1140
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1138

def last_vulnerability_update_time
  @last_vulnerability_update_time
end

#sbom_statusGoogle::Apis::OndemandscanningV1::SbomStatus

The status of an SBOM generation. Corresponds to the JSON property sbomStatus



1143
1144
1145
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1143

def sbom_status
  @sbom_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1150

def update!(**args)
  @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed)
  @analysis_error = args[:analysis_error] if args.key?(:analysis_error)
  @analysis_status = args[:analysis_status] if args.key?(:analysis_status)
  @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error)
  @archive_time = args[:archive_time] if args.key?(:archive_time)
  @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis)
  @cpe = args[:cpe] if args.key?(:cpe)
  @files = args[:files] if args.key?(:files)
  @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time)
  @last_vulnerability_update_time = args[:last_vulnerability_update_time] if args.key?(:last_vulnerability_update_time)
  @sbom_status = args[:sbom_status] if args.key?(:sbom_status)
end