Class: Google::Apis::OndemandscanningV1::ExploitPredictionScoringSystem
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::ExploitPredictionScoringSystem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Instance Attribute Summary collapse
-
#percentile ⇒ Float
The percentile of the current score, the proportion of all scored vulnerabilities with the same or a lower EPSS score Corresponds to the JSON property
percentile. -
#score ⇒ Float
The EPSS score representing the probability [0-1] of exploitation in the wild in the next 30 days Corresponds to the JSON property
score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExploitPredictionScoringSystem
constructor
A new instance of ExploitPredictionScoringSystem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExploitPredictionScoringSystem
Returns a new instance of ExploitPredictionScoringSystem.
1172 1173 1174 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1172 def initialize(**args) update!(**args) end |
Instance Attribute Details
#percentile ⇒ Float
The percentile of the current score, the proportion of all scored
vulnerabilities with the same or a lower EPSS score
Corresponds to the JSON property percentile
1164 1165 1166 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1164 def percentile @percentile end |
#score ⇒ Float
The EPSS score representing the probability [0-1] of exploitation in the wild
in the next 30 days
Corresponds to the JSON property score
1170 1171 1172 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1170 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1177 1178 1179 1180 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1177 def update!(**args) @percentile = args[:percentile] if args.key?(:percentile) @score = args[:score] if args.key?(:score) end |