Class: Google::Apis::OndemandscanningV1::FileHashes
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::FileHashes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileHashes
constructor
A new instance of FileHashes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileHashes
Returns a new instance of FileHashes.
1302 1303 1304 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1302 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_hash ⇒ Array<Google::Apis::OndemandscanningV1::HashProp>
Required. Collection of file hashes.
Corresponds to the JSON property fileHash
1300 1301 1302 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1300 def file_hash @file_hash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1307 1308 1309 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1307 def update!(**args) @file_hash = args[:file_hash] if args.key?(:file_hash) end |