Class: Google::Apis::OndemandscanningV1::FileLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Indicates the location at which a package was found.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileLocation

Returns a new instance of FileLocation.



1334
1335
1336
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_pathString

For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file. Corresponds to the JSON property filePath

Returns:

  • (String)


1320
1321
1322
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1320

def file_path
  @file_path
end

#layer_detailsGoogle::Apis::OndemandscanningV1::LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



1325
1326
1327
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1325

def layer_details
  @layer_details
end

#line_numberFixnum

Line number in the file where the package is found. Applies only to source repository scanning. Note: this field is marked as optional in other corresponding protos, but in edition 2023, the "optional" keyword is redundant. Corresponds to the JSON property lineNumber

Returns:

  • (Fixnum)


1332
1333
1334
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1332

def line_number
  @line_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1339
1340
1341
1342
1343
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1339

def update!(**args)
  @file_path = args[:file_path] if args.key?(:file_path)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
  @line_number = args[:line_number] if args.key?(:line_number)
end