Class: Google::Apis::OndemandscanningV1::Finding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Finding provides details for a single finding within an AISkillAnalysisOccurrence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Finding

Returns a new instance of Finding.



1327
1328
1329
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Category of the finding. Corresponds to the JSON property category

Returns:

  • (String)


1295
1296
1297
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1295

def category
  @category
end

#descriptionString

Detailed description of the finding. Corresponds to the JSON property description

Returns:

  • (String)


1300
1301
1302
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1300

def description
  @description
end

#file_pathString

Path to the file where the finding was detected. Corresponds to the JSON property filePath

Returns:

  • (String)


1305
1306
1307
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1305

def file_path
  @file_path
end

#rule_idString

Unique identifier of the rule that produced this finding. Corresponds to the JSON property ruleId

Returns:

  • (String)


1310
1311
1312
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1310

def rule_id
  @rule_id
end

#severityString

Severity of the finding. Corresponds to the JSON property severity

Returns:

  • (String)


1315
1316
1317
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1315

def severity
  @severity
end

#snippetString

Code snippet relevant to the finding. Corresponds to the JSON property snippet

Returns:

  • (String)


1320
1321
1322
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1320

def snippet
  @snippet
end

#titleString

Title of the finding. Corresponds to the JSON property title

Returns:

  • (String)


1325
1326
1327
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1325

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1332
1333
1334
1335
1336
1337
1338
1339
1340
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1332

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @description = args[:description] if args.key?(:description)
  @file_path = args[:file_path] if args.key?(:file_path)
  @rule_id = args[:rule_id] if args.key?(:rule_id)
  @severity = args[:severity] if args.key?(:severity)
  @snippet = args[:snippet] if args.key?(:snippet)
  @title = args[:title] if args.key?(:title)
end