Class: Google::Apis::OndemandscanningV1::Fingerprint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

A set of properties that uniquely identify a given Docker image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Fingerprint

Returns a new instance of Fingerprint.



1419
1420
1421
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#v1_nameString

Required. The layer ID of the final layer in the Docker image's v1 representation. Corresponds to the JSON property v1Name

Returns:

  • (String)


1405
1406
1407
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1405

def v1_name
  @v1_name
end

#v2_blobArray<String>

Required. The ordered list of v2 blobs that represent a given image. Corresponds to the JSON property v2Blob

Returns:

  • (Array<String>)


1410
1411
1412
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1410

def v2_blob
  @v2_blob
end

#v2_nameString

Output only. The name of the image's v2 blobs computed via: [bottom] := v2_blobbottom := sha256(v2_blob[N] + " " + v2_name[N+1]) Only the name of the final blob is kept. Corresponds to the JSON property v2Name

Returns:

  • (String)


1417
1418
1419
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1417

def v2_name
  @v2_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1424
1425
1426
1427
1428
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1424

def update!(**args)
  @v1_name = args[:v1_name] if args.key?(:v1_name)
  @v2_blob = args[:v2_blob] if args.key?(:v2_blob)
  @v2_name = args[:v2_name] if args.key?(:v2_name)
end