Class: Google::Apis::OndemandscanningV1::GrafeasV1BaseImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

BaseImage describes a base image of a container image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1BaseImage

Returns a new instance of GrafeasV1BaseImage.



1519
1520
1521
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1519

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#layer_countFixnum

The number of layers that the base image is composed of. Corresponds to the JSON property layerCount

Returns:

  • (Fixnum)


1502
1503
1504
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1502

def layer_count
  @layer_count
end

#nameString

The name of the base image. Corresponds to the JSON property name

Returns:

  • (String)


1507
1508
1509
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1507

def name
  @name
end

#registryString

The registry in which the base image is from. Corresponds to the JSON property registry

Returns:

  • (String)


1512
1513
1514
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1512

def registry
  @registry
end

#repositoryString

The repository name in which the base image is from. Corresponds to the JSON property repository

Returns:

  • (String)


1517
1518
1519
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1517

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1524
1525
1526
1527
1528
1529
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1524

def update!(**args)
  @layer_count = args[:layer_count] if args.key?(:layer_count)
  @name = args[:name] if args.key?(:name)
  @registry = args[:registry] if args.key?(:registry)
  @repository = args[:repository] if args.key?(:repository)
end