Class: Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Describes where the config file that kicked off the build came from. This is effectively a pointer to the source where buildConfig came from.
Instance Attribute Summary collapse
-
#digest ⇒ Hash<String,String>
Corresponds to the JSON property
digest. -
#entry_point ⇒ String
Corresponds to the JSON property
entryPoint. -
#uri ⇒ String
Corresponds to the JSON property
uri.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource
constructor
A new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource
Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource.
1631 1632 1633 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1631 def initialize(**args) update!(**args) end |
Instance Attribute Details
#digest ⇒ Hash<String,String>
Corresponds to the JSON property digest
1619 1620 1621 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1619 def digest @digest end |
#entry_point ⇒ String
Corresponds to the JSON property entryPoint
1624 1625 1626 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1624 def entry_point @entry_point end |
#uri ⇒ String
Corresponds to the JSON property uri
1629 1630 1631 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1629 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1636 1637 1638 1639 1640 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1636 def update!(**args) @digest = args[:digest] if args.key?(:digest) @entry_point = args[:entry_point] if args.key?(:entry_point) @uri = args[:uri] if args.key?(:uri) end |