Class: Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Identifies the event that kicked off the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation.



1655
1656
1657
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_sourceGoogle::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource

Describes where the config file that kicked off the build came from. This is effectively a pointer to the source where buildConfig came from. Corresponds to the JSON property configSource



1643
1644
1645
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1643

def config_source
  @config_source
end

#environmentHash<String,Object>

Corresponds to the JSON property environment

Returns:

  • (Hash<String,Object>)


1648
1649
1650
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1648

def environment
  @environment
end

#parametersHash<String,Object>

Corresponds to the JSON property parameters

Returns:

  • (Hash<String,Object>)


1653
1654
1655
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1653

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1660
1661
1662
1663
1664
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1660

def update!(**args)
  @config_source = args[:config_source] if args.key?(:config_source)
  @environment = args[:environment] if args.key?(:environment)
  @parameters = args[:parameters] if args.key?(:parameters)
end