Class: Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
Instance Attribute Summary collapse
-
#digest ⇒ Hash<String,String>
Corresponds to the JSON property
digest. -
#uri ⇒ String
Corresponds to the JSON property
uri.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial
constructor
A new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial
Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial.
1750 1751 1752 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#digest ⇒ Hash<String,String>
Corresponds to the JSON property digest
1743 1744 1745 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1743 def digest @digest end |
#uri ⇒ String
Corresponds to the JSON property uri
1748 1749 1750 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1748 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1755 1756 1757 1758 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1755 def update!(**args) @digest = args[:digest] if args.key?(:digest) @uri = args[:uri] if args.key?(:uri) end |