Class: Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Other properties of the build.
Instance Attribute Summary collapse
-
#build_finished_on ⇒ String
Corresponds to the JSON property
buildFinishedOn. -
#build_invocation_id ⇒ String
Corresponds to the JSON property
buildInvocationId. -
#build_started_on ⇒ String
Corresponds to the JSON property
buildStartedOn. -
#completeness ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaCompleteness
Indicates that the builder claims certain fields in this message to be complete.
-
#reproducible ⇒ Boolean
(also: #reproducible?)
Corresponds to the JSON property
reproducible.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
constructor
A new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata.
1792 1793 1794 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1792 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build_finished_on ⇒ String
Corresponds to the JSON property buildFinishedOn
1768 1769 1770 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1768 def build_finished_on @build_finished_on end |
#build_invocation_id ⇒ String
Corresponds to the JSON property buildInvocationId
1773 1774 1775 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1773 def build_invocation_id @build_invocation_id end |
#build_started_on ⇒ String
Corresponds to the JSON property buildStartedOn
1778 1779 1780 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1778 def build_started_on @build_started_on end |
#completeness ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaCompleteness
Indicates that the builder claims certain fields in this message to be
complete.
Corresponds to the JSON property completeness
1784 1785 1786 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1784 def completeness @completeness end |
#reproducible ⇒ Boolean Also known as: reproducible?
Corresponds to the JSON property reproducible
1789 1790 1791 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1789 def reproducible @reproducible end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1797 1798 1799 1800 1801 1802 1803 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1797 def update!(**args) @build_finished_on = args[:build_finished_on] if args.key?(:build_finished_on) @build_invocation_id = args[:build_invocation_id] if args.key?(:build_invocation_id) @build_started_on = args[:build_started_on] if args.key?(:build_started_on) @completeness = args[:completeness] if args.key?(:completeness) @reproducible = args[:reproducible] if args.key?(:reproducible) end |