Class: Google::Apis::OndemandscanningV1::ImageOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Details of the derived image portion of the DockerImage relationship. This image would be produced from a Dockerfile with FROM .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageOccurrence

Returns a new instance of ImageOccurrence.



1711
1712
1713
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1711

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_resource_urlString

Output only. This contains the base image URL for the derived image occurrence. Corresponds to the JSON property baseResourceUrl

Returns:

  • (String)


1691
1692
1693
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1691

def base_resource_url
  @base_resource_url
end

#distanceFixnum

Output only. The number of layers by which this image differs from the associated image basis. Corresponds to the JSON property distance

Returns:

  • (Fixnum)


1697
1698
1699
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1697

def distance
  @distance
end

#fingerprintGoogle::Apis::OndemandscanningV1::Fingerprint

A set of properties that uniquely identify a given Docker image. Corresponds to the JSON property fingerprint



1702
1703
1704
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1702

def fingerprint
  @fingerprint
end

#layer_infoArray<Google::Apis::OndemandscanningV1::Layer>

This contains layer-specific metadata, if populated it has length "distance" and is ordered with [distance] being the layer immediately following the base image and [1] being the final layer. Corresponds to the JSON property layerInfo



1709
1710
1711
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1709

def layer_info
  @layer_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1716
1717
1718
1719
1720
1721
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1716

def update!(**args)
  @base_resource_url = args[:base_resource_url] if args.key?(:base_resource_url)
  @distance = args[:distance] if args.key?(:distance)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @layer_info = args[:layer_info] if args.key?(:layer_info)
end