Class: Google::Apis::OndemandscanningV1::IngestionSource
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::IngestionSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Indicates where an extracted package originates from.
Instance Attribute Summary collapse
-
#attachment_uri ⇒ String
The attachment URI that this package was extracted from.
-
#resource_url ⇒ String
The resource URL of the resource that was scanned to find this package.
-
#source ⇒ String
Corresponds to the JSON property
source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestionSource
constructor
A new instance of IngestionSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestionSource
Returns a new instance of IngestionSource.
2055 2056 2057 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_uri ⇒ String
The attachment URI that this package was extracted from.
Corresponds to the JSON property attachmentUri
2043 2044 2045 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2043 def @attachment_uri end |
#resource_url ⇒ String
The resource URL of the resource that was scanned to find this package.
Corresponds to the JSON property resourceUrl
2048 2049 2050 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2048 def resource_url @resource_url end |
#source ⇒ String
Corresponds to the JSON property source
2053 2054 2055 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2053 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2060 2061 2062 2063 2064 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2060 def update!(**args) @attachment_uri = args[:attachment_uri] if args.key?(:attachment_uri) @resource_url = args[:resource_url] if args.key?(:resource_url) @source = args[:source] if args.key?(:source) end |