Class: Google::Apis::OndemandscanningV1::Layer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Layer holds metadata specific to a layer of a Docker image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Layer

Returns a new instance of Layer.



2155
2156
2157
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argumentsString

The recovered arguments to the Dockerfile directive. Corresponds to the JSON property arguments

Returns:

  • (String)


2147
2148
2149
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2147

def arguments
  @arguments
end

#directiveString

Required. The recovered Dockerfile directive used to construct this layer. See https://docs.docker.com/engine/reference/builder/ for more information. Corresponds to the JSON property directive

Returns:

  • (String)


2153
2154
2155
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2153

def directive
  @directive
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2160
2161
2162
2163
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2160

def update!(**args)
  @arguments = args[:arguments] if args.key?(:arguments)
  @directive = args[:directive] if args.key?(:directive)
end