Class: Google::Apis::OndemandscanningV1::Metadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Other properties of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Metadata

Returns a new instance of Metadata.



2235
2236
2237
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_finished_onString

The timestamp of when the build completed. Corresponds to the JSON property buildFinishedOn

Returns:

  • (String)


2208
2209
2210
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2208

def build_finished_on
  @build_finished_on
end

#build_invocation_idString

Identifies the particular build invocation, which can be useful for finding associated logs or other ad-hoc analysis. The value SHOULD be globally unique, per in-toto Provenance spec. Corresponds to the JSON property buildInvocationId

Returns:

  • (String)


2215
2216
2217
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2215

def build_invocation_id
  @build_invocation_id
end

#build_started_onString

The timestamp of when the build started. Corresponds to the JSON property buildStartedOn

Returns:

  • (String)


2220
2221
2222
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2220

def build_started_on
  @build_started_on
end

#completenessGoogle::Apis::OndemandscanningV1::Completeness

Indicates that the builder claims certain fields in this message to be complete. Corresponds to the JSON property completeness



2226
2227
2228
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2226

def completeness
  @completeness
end

#reproducibleBoolean Also known as: reproducible?

If true, the builder claims that running the recipe on materials will produce bit-for-bit identical output. Corresponds to the JSON property reproducible

Returns:

  • (Boolean)


2232
2233
2234
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2232

def reproducible
  @reproducible
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2240
2241
2242
2243
2244
2245
2246
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2240

def update!(**args)
  @build_finished_on = args[:build_finished_on] if args.key?(:build_finished_on)
  @build_invocation_id = args[:build_invocation_id] if args.key?(:build_invocation_id)
  @build_started_on = args[:build_started_on] if args.key?(:build_started_on)
  @completeness = args[:completeness] if args.key?(:completeness)
  @reproducible = args[:reproducible] if args.key?(:reproducible)
end