Class: Google::Apis::OndemandscanningV1::Recipe

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Recipe

Returns a new instance of Recipe.



3239
3240
3241
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argumentsArray<Hash<String,Object>>

Collection of all external inputs that influenced the build on top of recipe. definedInMaterial and recipe.entryPoint. For example, if the recipe type were " make", then this might be the flags passed to make aside from the target, which is captured in recipe.entryPoint. Since the arguments field can greatly vary in structure, depending on the builder and recipe type, this is of form " Any". Corresponds to the JSON property arguments

Returns:

  • (Array<Hash<String,Object>>)


3205
3206
3207
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3205

def arguments
  @arguments
end

#defined_in_materialFixnum

Index in materials containing the recipe steps that are not implied by recipe. type. For example, if the recipe type were "make", then this would point to the source containing the Makefile, not the make program itself. Set to -1 if the recipe doesn't come from a material, as zero is default unset value for int64. Corresponds to the JSON property definedInMaterial

Returns:

  • (Fixnum)


3214
3215
3216
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3214

def defined_in_material
  @defined_in_material
end

#entry_pointString

String identifying the entry point into the build. This is often a path to a configuration file and/or a target label within that file. The syntax and meaning are defined by recipe.type. For example, if the recipe type were "make" , then this would reference the directory in which to run make as well as which target to use. Corresponds to the JSON property entryPoint

Returns:

  • (String)


3223
3224
3225
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3223

def entry_point
  @entry_point
end

#environmentArray<Hash<String,Object>>

Any other builder-controlled inputs necessary for correctly evaluating the recipe. Usually only needed for reproducing the build but not evaluated as part of policy. Since the environment field can greatly vary in structure, depending on the builder and recipe type, this is of form "Any". Corresponds to the JSON property environment

Returns:

  • (Array<Hash<String,Object>>)


3231
3232
3233
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3231

def environment
  @environment
end

#typeString

URI indicating what type of recipe was performed. It determines the meaning of recipe.entryPoint, recipe.arguments, recipe.environment, and materials. Corresponds to the JSON property type

Returns:

  • (String)


3237
3238
3239
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3237

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3244
3245
3246
3247
3248
3249
3250
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3244

def update!(**args)
  @arguments = args[:arguments] if args.key?(:arguments)
  @defined_in_material = args[:defined_in_material] if args.key?(:defined_in_material)
  @entry_point = args[:entry_point] if args.key?(:entry_point)
  @environment = args[:environment] if args.key?(:environment)
  @type = args[:type] if args.key?(:type)
end