Class: Google::Apis::OndemandscanningV1::Risk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Risk

Returns a new instance of Risk.



3407
3408
3409
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cisa_kevGoogle::Apis::OndemandscanningV1::CisaKnownExploitedVulnerabilities

CISA maintains the authoritative source of vulnerabilities that have been exploited in the wild. Corresponds to the JSON property cisaKev



3399
3400
3401
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3399

def cisa_kev
  @cisa_kev
end

#epssGoogle::Apis::OndemandscanningV1::ExploitPredictionScoringSystem

The Exploit Prediction Scoring System (EPSS) estimates the likelihood ( probability) that a software vulnerability will be exploited in the wild. Corresponds to the JSON property epss



3405
3406
3407
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3405

def epss
  @epss
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3412
3413
3414
3415
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3412

def update!(**args)
  @cisa_kev = args[:cisa_kev] if args.key?(:cisa_kev)
  @epss = args[:epss] if args.key?(:epss)
end