Class: Google::Apis::OndemandscanningV1::SecretLocation
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::SecretLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
The location of the secret.
Instance Attribute Summary collapse
-
#file_location ⇒ Google::Apis::OndemandscanningV1::GrafeasV1FileLocation
Indicates the location at which a package was found.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecretLocation
constructor
A new instance of SecretLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecretLocation
Returns a new instance of SecretLocation.
3249 3250 3251 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3249 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_location ⇒ Google::Apis::OndemandscanningV1::GrafeasV1FileLocation
Indicates the location at which a package was found.
Corresponds to the JSON property fileLocation
3247 3248 3249 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3247 def file_location @file_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3254 3255 3256 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3254 def update!(**args) @file_location = args[:file_location] if args.key?(:file_location) end |