Class: Google::Apis::OndemandscanningV1::SlsaProvenanceZeroTwo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

See full explanation of fields at slsa.dev/provenance/v0.2.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenanceZeroTwo

Returns a new instance of SlsaProvenanceZeroTwo.



3769
3770
3771
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_configHash<String,Object>

Corresponds to the JSON property buildConfig

Returns:

  • (Hash<String,Object>)


3741
3742
3743
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3741

def build_config
  @build_config
end

#build_typeString

Corresponds to the JSON property buildType

Returns:

  • (String)


3746
3747
3748
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3746

def build_type
  @build_type
end

#builderGoogle::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance. Corresponds to the JSON property builder



3752
3753
3754
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3752

def builder
  @builder
end

#invocationGoogle::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation

Identifies the event that kicked off the build. Corresponds to the JSON property invocation



3757
3758
3759
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3757

def invocation
  @invocation
end

#materialsArray<Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial>

Corresponds to the JSON property materials



3762
3763
3764
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3762

def materials
  @materials
end

#metadataGoogle::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



3767
3768
3769
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3767

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3774
3775
3776
3777
3778
3779
3780
3781
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3774

def update!(**args)
  @build_config = args[:build_config] if args.key?(:build_config)
  @build_type = args[:build_type] if args.key?(:build_type)
  @builder = args[:builder] if args.key?(:builder)
  @invocation = args[:invocation] if args.key?(:invocation)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
end