Class: Google::Apis::OndemandscanningV1::Source

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Source describes the location of the source used for the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Source

Returns a new instance of Source.



4037
4038
4039
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_contextsArray<Google::Apis::OndemandscanningV1::SourceContext>

If provided, some of the source code used for the build may be found in these locations, in the case where the source repository had multiple remotes or submodules. This list will not include the context specified in the context field. Corresponds to the JSON property additionalContexts



4015
4016
4017
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4015

def additional_contexts
  @additional_contexts
end

#artifact_storage_source_uriString

If provided, the input binary artifacts for the build came from this location. Corresponds to the JSON property artifactStorageSourceUri

Returns:

  • (String)


4020
4021
4022
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4020

def artifact_storage_source_uri
  @artifact_storage_source_uri
end

#contextGoogle::Apis::OndemandscanningV1::SourceContext

A SourceContext is a reference to a tree of files. A SourceContext together with a path point to a unique revision of a single file or directory. Corresponds to the JSON property context



4026
4027
4028
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4026

def context
  @context
end

#file_hashesHash<String,Google::Apis::OndemandscanningV1::FileHashes>

Hash(es) of the build source, which can be used to verify that the original source integrity was maintained in the build. The keys to this map are file paths used as build source and the values contain the hash values for those files. If the build source came in a single package such as a gzipped tarfile ( .tar.gz), the FileHash will be for the single path to that file. Corresponds to the JSON property fileHashes



4035
4036
4037
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4035

def file_hashes
  @file_hashes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4042
4043
4044
4045
4046
4047
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4042

def update!(**args)
  @additional_contexts = args[:additional_contexts] if args.key?(:additional_contexts)
  @artifact_storage_source_uri = args[:artifact_storage_source_uri] if args.key?(:artifact_storage_source_uri)
  @context = args[:context] if args.key?(:context)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
end