Class: Google::Apis::OndemandscanningV1::SourceContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

A SourceContext is a reference to a tree of files. A SourceContext together with a path point to a unique revision of a single file or directory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceContext

Returns a new instance of SourceContext.



3855
3856
3857
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_repoGoogle::Apis::OndemandscanningV1::CloudRepoSourceContext

A CloudRepoSourceContext denotes a particular revision in a Google Cloud Source Repo. Corresponds to the JSON property cloudRepo



3837
3838
3839
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3837

def cloud_repo
  @cloud_repo
end

#gerritGoogle::Apis::OndemandscanningV1::GerritSourceContext

A SourceContext referring to a Gerrit project. Corresponds to the JSON property gerrit



3842
3843
3844
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3842

def gerrit
  @gerrit
end

#gitGoogle::Apis::OndemandscanningV1::GitSourceContext

A GitSourceContext denotes a particular revision in a third party Git repository (e.g., GitHub). Corresponds to the JSON property git



3848
3849
3850
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3848

def git
  @git
end

#labelsHash<String,String>

Labels with user defined metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3853
3854
3855
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3853

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3860
3861
3862
3863
3864
3865
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3860

def update!(**args)
  @cloud_repo = args[:cloud_repo] if args.key?(:cloud_repo)
  @gerrit = args[:gerrit] if args.key?(:gerrit)
  @git = args[:git] if args.key?(:git)
  @labels = args[:labels] if args.key?(:labels)
end