Class: Google::Apis::OndemandscanningV1::WindowsUpdate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Windows Update represents the metadata about the update for the Windows operating system. The fields in this message come from the Windows Update API documented at https://docs.microsoft.com/en-us/windows/win32/api/wuapi/nn- wuapi-iupdate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WindowsUpdate

Returns a new instance of WindowsUpdate.



4310
4311
4312
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesArray<Google::Apis::OndemandscanningV1::Category>

The list of categories to which the update belongs. Corresponds to the JSON property categories



4278
4279
4280
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4278

def categories
  @categories
end

#descriptionString

The localized description of the update. Corresponds to the JSON property description

Returns:

  • (String)


4283
4284
4285
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4283

def description
  @description
end

#identityGoogle::Apis::OndemandscanningV1::Identity

The unique identifier of the update. Corresponds to the JSON property identity



4288
4289
4290
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4288

def identity
  @identity
end

#kb_article_idsArray<String>

The Microsoft Knowledge Base article IDs that are associated with the update. Corresponds to the JSON property kbArticleIds

Returns:

  • (Array<String>)


4293
4294
4295
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4293

def kb_article_ids
  @kb_article_ids
end

#last_published_timestampString

The last published timestamp of the update. Corresponds to the JSON property lastPublishedTimestamp

Returns:

  • (String)


4298
4299
4300
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4298

def last_published_timestamp
  @last_published_timestamp
end

#support_urlString

The hyperlink to the support information for the update. Corresponds to the JSON property supportUrl

Returns:

  • (String)


4303
4304
4305
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4303

def support_url
  @support_url
end

#titleString

The localized title of the update. Corresponds to the JSON property title

Returns:

  • (String)


4308
4309
4310
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4308

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4315
4316
4317
4318
4319
4320
4321
4322
4323
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4315

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @description = args[:description] if args.key?(:description)
  @identity = args[:identity] if args.key?(:identity)
  @kb_article_ids = args[:kb_article_ids] if args.key?(:kb_article_ids)
  @last_published_timestamp = args[:last_published_timestamp] if args.key?(:last_published_timestamp)
  @support_url = args[:support_url] if args.key?(:support_url)
  @title = args[:title] if args.key?(:title)
end