Class: Google::Apis::OndemandscanningV1::BaseImage
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::BaseImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
BaseImage describes a base image of a container image.
Instance Attribute Summary collapse
-
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
-
#name ⇒ String
The name of the base image.
-
#registry ⇒ String
The registry in which the base image is from.
-
#repository ⇒ String
The repository name in which the base image is from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BaseImage
constructor
A new instance of BaseImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BaseImage
Returns a new instance of BaseImage.
329 330 331 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 329 def initialize(**args) update!(**args) end |
Instance Attribute Details
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
Corresponds to the JSON property layerCount
312 313 314 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 312 def layer_count @layer_count end |
#name ⇒ String
The name of the base image.
Corresponds to the JSON property name
317 318 319 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 317 def name @name end |
#registry ⇒ String
The registry in which the base image is from.
Corresponds to the JSON property registry
322 323 324 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 322 def registry @registry end |
#repository ⇒ String
The repository name in which the base image is from.
Corresponds to the JSON property repository
327 328 329 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 327 def repository @repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
334 335 336 337 338 339 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 334 def update!(**args) @layer_count = args[:layer_count] if args.key?(:layer_count) @name = args[:name] if args.key?(:name) @registry = args[:registry] if args.key?(:registry) @repository = args[:repository] if args.key?(:repository) end |