Class: Google::Apis::OndemandscanningV1::BinarySourceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BinarySourceInfo

Returns a new instance of BinarySourceInfo.



331
332
333
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binary_versionGoogle::Apis::OndemandscanningV1::PackageVersion

The binary package. This is significant when the source is different than the binary itself. Historically if they've differed, we've stored the name of the source and its version in the package/version fields, but we should also store the binary package info, as that's what's actually installed. Corresponds to the JSON property binaryVersion



321
322
323
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 321

def binary_version
  @binary_version
end

#source_versionGoogle::Apis::OndemandscanningV1::PackageVersion

The source package. Similar to the above, this is significant when the source is different than the binary itself. Since the top-level package/version fields are based on an if/else, we need a separate field for both binary and source if we want to know definitively where the data is coming from. Corresponds to the JSON property sourceVersion



329
330
331
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 329

def source_version
  @source_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



336
337
338
339
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 336

def update!(**args)
  @binary_version = args[:binary_version] if args.key?(:binary_version)
  @source_version = args[:source_version] if args.key?(:source_version)
end