Class: Google::Apis::OndemandscanningV1::Cvss

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Cvss

Returns a new instance of Cvss.



668
669
670
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attack_complexityString

Corresponds to the JSON property attackComplexity

Returns:

  • (String)


610
611
612
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 610

def attack_complexity
  @attack_complexity
end

#attack_vectorString

Base Metrics Represents the intrinsic characteristics of a vulnerability that are constant over time and across user environments. Corresponds to the JSON property attackVector

Returns:

  • (String)


616
617
618
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 616

def attack_vector
  @attack_vector
end

#authenticationString

Corresponds to the JSON property authentication

Returns:

  • (String)


621
622
623
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 621

def authentication
  @authentication
end

#availability_impactString

Corresponds to the JSON property availabilityImpact

Returns:

  • (String)


626
627
628
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 626

def availability_impact
  @availability_impact
end

#base_scoreFloat

The base score is a function of the base metric scores. Corresponds to the JSON property baseScore

Returns:

  • (Float)


631
632
633
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 631

def base_score
  @base_score
end

#confidentiality_impactString

Corresponds to the JSON property confidentialityImpact

Returns:

  • (String)


636
637
638
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 636

def confidentiality_impact
  @confidentiality_impact
end

#exploitability_scoreFloat

Corresponds to the JSON property exploitabilityScore

Returns:

  • (Float)


641
642
643
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 641

def exploitability_score
  @exploitability_score
end

#impact_scoreFloat

Corresponds to the JSON property impactScore

Returns:

  • (Float)


646
647
648
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 646

def impact_score
  @impact_score
end

#integrity_impactString

Corresponds to the JSON property integrityImpact

Returns:

  • (String)


651
652
653
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 651

def integrity_impact
  @integrity_impact
end

#privileges_requiredString

Corresponds to the JSON property privilegesRequired

Returns:

  • (String)


656
657
658
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 656

def privileges_required
  @privileges_required
end

#scopeString

Corresponds to the JSON property scope

Returns:

  • (String)


661
662
663
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 661

def scope
  @scope
end

#user_interactionString

Corresponds to the JSON property userInteraction

Returns:

  • (String)


666
667
668
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 666

def user_interaction
  @user_interaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



673
674
675
676
677
678
679
680
681
682
683
684
685
686
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 673

def update!(**args)
  @attack_complexity = args[:attack_complexity] if args.key?(:attack_complexity)
  @attack_vector = args[:attack_vector] if args.key?(:attack_vector)
  @authentication = args[:authentication] if args.key?(:authentication)
  @availability_impact = args[:availability_impact] if args.key?(:availability_impact)
  @base_score = args[:base_score] if args.key?(:base_score)
  @confidentiality_impact = args[:confidentiality_impact] if args.key?(:confidentiality_impact)
  @exploitability_score = args[:exploitability_score] if args.key?(:exploitability_score)
  @impact_score = args[:impact_score] if args.key?(:impact_score)
  @integrity_impact = args[:integrity_impact] if args.key?(:integrity_impact)
  @privileges_required = args[:privileges_required] if args.key?(:privileges_required)
  @scope = args[:scope] if args.key?(:scope)
  @user_interaction = args[:user_interaction] if args.key?(:user_interaction)
end