Class: Google::Apis::OndemandscanningV1::DeploymentOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

The period during which some deployable was active in a runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeploymentOccurrence

Returns a new instance of DeploymentOccurrence.



1003
1004
1005
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Address of the runtime element hosting this deployment. Corresponds to the JSON property address

Returns:

  • (String)


970
971
972
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 970

def address
  @address
end

#configString

Configuration used to create this deployment. Corresponds to the JSON property config

Returns:

  • (String)


975
976
977
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 975

def config
  @config
end

#deploy_timeString

Required. Beginning of the lifetime of this deployment. Corresponds to the JSON property deployTime

Returns:

  • (String)


980
981
982
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 980

def deploy_time
  @deploy_time
end

#platformString

Platform hosting this deployment. Corresponds to the JSON property platform

Returns:

  • (String)


985
986
987
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 985

def platform
  @platform
end

#resource_uriArray<String>

Output only. Resource URI for the artifact being deployed taken from the deployable field with the same name. Corresponds to the JSON property resourceUri

Returns:

  • (Array<String>)


991
992
993
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 991

def resource_uri
  @resource_uri
end

#undeploy_timeString

End of the lifetime of this deployment. Corresponds to the JSON property undeployTime

Returns:

  • (String)


996
997
998
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 996

def undeploy_time
  @undeploy_time
end

#user_emailString

Identity of the user that triggered this deployment. Corresponds to the JSON property userEmail

Returns:

  • (String)


1001
1002
1003
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1001

def user_email
  @user_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1008
1009
1010
1011
1012
1013
1014
1015
1016
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1008

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @config = args[:config] if args.key?(:config)
  @deploy_time = args[:deploy_time] if args.key?(:deploy_time)
  @platform = args[:platform] if args.key?(:platform)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time)
  @user_email = args[:user_email] if args.key?(:user_email)
end