Class: Google::Apis::OndemandscanningV1::DiscoveryOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Provides information about the analysis status of a discovered resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveryOccurrence

Returns a new instance of DiscoveryOccurrence.



1133
1134
1135
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_completedGoogle::Apis::OndemandscanningV1::AnalysisCompleted

Indicates which analysis completed successfully. Multiple types of analysis can be performed on a single resource. Corresponds to the JSON property analysisCompleted



1074
1075
1076
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1074

def analysis_completed
  @analysis_completed
end

#analysis_errorArray<Google::Apis::OndemandscanningV1::Status>

Indicates any errors encountered during analysis of a resource. There could be 0 or more of these errors. Corresponds to the JSON property analysisError



1080
1081
1082
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1080

def analysis_error
  @analysis_error
end

#analysis_statusString

The status of discovery for the resource. Corresponds to the JSON property analysisStatus

Returns:

  • (String)


1085
1086
1087
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1085

def analysis_status
  @analysis_status
end

#analysis_status_errorGoogle::Apis::OndemandscanningV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property analysisStatusError



1095
1096
1097
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1095

def analysis_status_error
  @analysis_status_error
end

#archive_timeString

Output only. The time occurrences related to this discovery occurrence were archived. Corresponds to the JSON property archiveTime

Returns:

  • (String)


1101
1102
1103
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1101

def archive_time
  @archive_time
end

#continuous_analysisString

Whether the resource is continuously analyzed. Corresponds to the JSON property continuousAnalysis

Returns:

  • (String)


1106
1107
1108
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1106

def continuous_analysis
  @continuous_analysis
end

#cpeString

The CPE of the resource being scanned. Corresponds to the JSON property cpe

Returns:

  • (String)


1111
1112
1113
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1111

def cpe
  @cpe
end

#filesArray<Google::Apis::OndemandscanningV1::File>

Files that make up the resource described by the occurrence. Corresponds to the JSON property files



1116
1117
1118
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1116

def files
  @files
end

#last_scan_timeString

The last time this resource was scanned. Corresponds to the JSON property lastScanTime

Returns:

  • (String)


1121
1122
1123
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1121

def last_scan_time
  @last_scan_time
end

#last_vulnerability_update_timeString

The last time vulnerability scan results changed. Corresponds to the JSON property lastVulnerabilityUpdateTime

Returns:

  • (String)


1126
1127
1128
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1126

def last_vulnerability_update_time
  @last_vulnerability_update_time
end

#sbom_statusGoogle::Apis::OndemandscanningV1::SbomStatus

The status of an SBOM generation. Corresponds to the JSON property sbomStatus



1131
1132
1133
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1131

def sbom_status
  @sbom_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1138

def update!(**args)
  @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed)
  @analysis_error = args[:analysis_error] if args.key?(:analysis_error)
  @analysis_status = args[:analysis_status] if args.key?(:analysis_status)
  @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error)
  @archive_time = args[:archive_time] if args.key?(:archive_time)
  @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis)
  @cpe = args[:cpe] if args.key?(:cpe)
  @files = args[:files] if args.key?(:files)
  @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time)
  @last_vulnerability_update_time = args[:last_vulnerability_update_time] if args.key?(:last_vulnerability_update_time)
  @sbom_status = args[:sbom_status] if args.key?(:sbom_status)
end