Class: Google::Apis::OndemandscanningV1::DiscoveryOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Provides information about the analysis status of a discovered resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveryOccurrence

Returns a new instance of DiscoveryOccurrence.



1061
1062
1063
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1061

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_completedGoogle::Apis::OndemandscanningV1::AnalysisCompleted

Indicates which analysis completed successfully. Multiple types of analysis can be performed on a single resource. Corresponds to the JSON property analysisCompleted



1002
1003
1004
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1002

def analysis_completed
  @analysis_completed
end

#analysis_errorArray<Google::Apis::OndemandscanningV1::Status>

Indicates any errors encountered during analysis of a resource. There could be 0 or more of these errors. Corresponds to the JSON property analysisError



1008
1009
1010
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1008

def analysis_error
  @analysis_error
end

#analysis_statusString

The status of discovery for the resource. Corresponds to the JSON property analysisStatus

Returns:

  • (String)


1013
1014
1015
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1013

def analysis_status
  @analysis_status
end

#analysis_status_errorGoogle::Apis::OndemandscanningV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property analysisStatusError



1023
1024
1025
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1023

def analysis_status_error
  @analysis_status_error
end

#archive_timeString

Output only. The time occurrences related to this discovery occurrence were archived. Corresponds to the JSON property archiveTime

Returns:

  • (String)


1029
1030
1031
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1029

def archive_time
  @archive_time
end

#continuous_analysisString

Whether the resource is continuously analyzed. Corresponds to the JSON property continuousAnalysis

Returns:

  • (String)


1034
1035
1036
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1034

def continuous_analysis
  @continuous_analysis
end

#cpeString

The CPE of the resource being scanned. Corresponds to the JSON property cpe

Returns:

  • (String)


1039
1040
1041
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1039

def cpe
  @cpe
end

#filesArray<Google::Apis::OndemandscanningV1::File>

Files that make up the resource described by the occurrence. Corresponds to the JSON property files



1044
1045
1046
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1044

def files
  @files
end

#last_scan_timeString

The last time this resource was scanned. Corresponds to the JSON property lastScanTime

Returns:

  • (String)


1049
1050
1051
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1049

def last_scan_time
  @last_scan_time
end

#last_vulnerability_update_timeString

The last time vulnerability scan results changed. Corresponds to the JSON property lastVulnerabilityUpdateTime

Returns:

  • (String)


1054
1055
1056
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1054

def last_vulnerability_update_time
  @last_vulnerability_update_time
end

#sbom_statusGoogle::Apis::OndemandscanningV1::SbomStatus

The status of an SBOM generation. Corresponds to the JSON property sbomStatus



1059
1060
1061
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1059

def sbom_status
  @sbom_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1066

def update!(**args)
  @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed)
  @analysis_error = args[:analysis_error] if args.key?(:analysis_error)
  @analysis_status = args[:analysis_status] if args.key?(:analysis_status)
  @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error)
  @archive_time = args[:archive_time] if args.key?(:archive_time)
  @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis)
  @cpe = args[:cpe] if args.key?(:cpe)
  @files = args[:files] if args.key?(:files)
  @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time)
  @last_vulnerability_update_time = args[:last_vulnerability_update_time] if args.key?(:last_vulnerability_update_time)
  @sbom_status = args[:sbom_status] if args.key?(:sbom_status)
end