Class: Google::Apis::OndemandscanningV1::ExploitPredictionScoringSystem
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::ExploitPredictionScoringSystem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Instance Attribute Summary collapse
-
#percentile ⇒ Float
The percentile of the current score, the proportion of all scored vulnerabilities with the same or a lower EPSS score Corresponds to the JSON property
percentile. -
#score ⇒ Float
The EPSS score representing the probability [0-1] of exploitation in the wild in the next 30 days Corresponds to the JSON property
score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExploitPredictionScoringSystem
constructor
A new instance of ExploitPredictionScoringSystem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExploitPredictionScoringSystem
Returns a new instance of ExploitPredictionScoringSystem.
1160 1161 1162 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#percentile ⇒ Float
The percentile of the current score, the proportion of all scored
vulnerabilities with the same or a lower EPSS score
Corresponds to the JSON property percentile
1152 1153 1154 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1152 def percentile @percentile end |
#score ⇒ Float
The EPSS score representing the probability [0-1] of exploitation in the wild
in the next 30 days
Corresponds to the JSON property score
1158 1159 1160 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1158 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1165 1166 1167 1168 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1165 def update!(**args) @percentile = args[:percentile] if args.key?(:percentile) @score = args[:score] if args.key?(:score) end |