Class: Google::Apis::OndemandscanningV1::FileHashes
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::FileHashes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileHashes
constructor
A new instance of FileHashes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileHashes
Returns a new instance of FileHashes.
1218 1219 1220 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1218 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_hash ⇒ Array<Google::Apis::OndemandscanningV1::HashProp>
Required. Collection of file hashes.
Corresponds to the JSON property fileHash
1216 1217 1218 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1216 def file_hash @file_hash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1223 1224 1225 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1223 def update!(**args) @file_hash = args[:file_hash] if args.key?(:file_hash) end |