Class: Google::Apis::OndemandscanningV1::FileHashes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileHashes

Returns a new instance of FileHashes.



1206
1207
1208
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashArray<Google::Apis::OndemandscanningV1::HashProp>

Required. Collection of file hashes. Corresponds to the JSON property fileHash



1204
1205
1206
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1204

def file_hash
  @file_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1211
1212
1213
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1211

def update!(**args)
  @file_hash = args[:file_hash] if args.key?(:file_hash)
end