Class: Google::Apis::OndemandscanningV1::FileLocation
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::FileLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Indicates the location at which a package was found.
Instance Attribute Summary collapse
-
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file.
-
#layer_details ⇒ Google::Apis::OndemandscanningV1::LayerDetails
Details about the layer a package was found in.
-
#line_number ⇒ Fixnum
Line number in the file where the package is found.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileLocation
constructor
A new instance of FileLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileLocation
Returns a new instance of FileLocation.
1322 1323 1324 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1322 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the
path to war file combined with the path to jar file.
Corresponds to the JSON property filePath
1308 1309 1310 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1308 def file_path @file_path end |
#layer_details ⇒ Google::Apis::OndemandscanningV1::LayerDetails
Details about the layer a package was found in.
Corresponds to the JSON property layerDetails
1313 1314 1315 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1313 def layer_details @layer_details end |
#line_number ⇒ Fixnum
Line number in the file where the package is found. Applies only to source
repository scanning. Note: this field is marked as optional in other
corresponding protos, but in edition 2023, the "optional" keyword is redundant.
Corresponds to the JSON property lineNumber
1320 1321 1322 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1320 def line_number @line_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1327 1328 1329 1330 1331 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1327 def update!(**args) @file_path = args[:file_path] if args.key?(:file_path) @layer_details = args[:layer_details] if args.key?(:layer_details) @line_number = args[:line_number] if args.key?(:line_number) end |