Class: Google::Apis::OndemandscanningV1::FileLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Indicates the location at which a package was found.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileLocation

Returns a new instance of FileLocation.



1268
1269
1270
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_pathString

For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file. Corresponds to the JSON property filePath

Returns:

  • (String)


1261
1262
1263
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1261

def file_path
  @file_path
end

#layer_detailsGoogle::Apis::OndemandscanningV1::LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



1266
1267
1268
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1266

def layer_details
  @layer_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1273
1274
1275
1276
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1273

def update!(**args)
  @file_path = args[:file_path] if args.key?(:file_path)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
end