Class: Google::Apis::OndemandscanningV1::Finding
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::Finding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Finding provides details for a single finding within an AISkillAnalysisOccurrence.
Instance Attribute Summary collapse
-
#category ⇒ String
Category of the finding.
-
#description ⇒ String
Detailed description of the finding.
-
#file_path ⇒ String
Path to the file where the finding was detected.
-
#rule_id ⇒ String
Unique identifier of the rule that produced this finding.
-
#severity ⇒ String
Severity of the finding.
-
#snippet ⇒ String
Code snippet relevant to the finding.
-
#title ⇒ String
Title of the finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Finding
constructor
A new instance of Finding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Finding
Returns a new instance of Finding.
1319 1320 1321 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1319 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
Category of the finding.
Corresponds to the JSON property category
1287 1288 1289 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1287 def category @category end |
#description ⇒ String
Detailed description of the finding.
Corresponds to the JSON property description
1292 1293 1294 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1292 def description @description end |
#file_path ⇒ String
Path to the file where the finding was detected.
Corresponds to the JSON property filePath
1297 1298 1299 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1297 def file_path @file_path end |
#rule_id ⇒ String
Unique identifier of the rule that produced this finding.
Corresponds to the JSON property ruleId
1302 1303 1304 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1302 def rule_id @rule_id end |
#severity ⇒ String
Severity of the finding.
Corresponds to the JSON property severity
1307 1308 1309 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1307 def severity @severity end |
#snippet ⇒ String
Code snippet relevant to the finding.
Corresponds to the JSON property snippet
1312 1313 1314 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1312 def snippet @snippet end |
#title ⇒ String
Title of the finding.
Corresponds to the JSON property title
1317 1318 1319 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1317 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1324 1325 1326 1327 1328 1329 1330 1331 1332 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1324 def update!(**args) @category = args[:category] if args.key?(:category) @description = args[:description] if args.key?(:description) @file_path = args[:file_path] if args.key?(:file_path) @rule_id = args[:rule_id] if args.key?(:rule_id) @severity = args[:severity] if args.key?(:severity) @snippet = args[:snippet] if args.key?(:snippet) @title = args[:title] if args.key?(:title) end |