Class: Google::Apis::OndemandscanningV1::GrafeasV1BaseImage
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::GrafeasV1BaseImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
BaseImage describes a base image of a container image.
Instance Attribute Summary collapse
-
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
-
#name ⇒ String
The name of the base image.
-
#registry ⇒ String
The registry in which the base image is from.
-
#repository ⇒ String
The repository name in which the base image is from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1BaseImage
constructor
A new instance of GrafeasV1BaseImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1BaseImage
Returns a new instance of GrafeasV1BaseImage.
1465 1466 1467 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1465 def initialize(**args) update!(**args) end |
Instance Attribute Details
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
Corresponds to the JSON property layerCount
1448 1449 1450 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1448 def layer_count @layer_count end |
#name ⇒ String
The name of the base image.
Corresponds to the JSON property name
1453 1454 1455 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1453 def name @name end |
#registry ⇒ String
The registry in which the base image is from.
Corresponds to the JSON property registry
1458 1459 1460 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1458 def registry @registry end |
#repository ⇒ String
The repository name in which the base image is from.
Corresponds to the JSON property repository
1463 1464 1465 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1463 def repository @repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1470 1471 1472 1473 1474 1475 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1470 def update!(**args) @layer_count = args[:layer_count] if args.key?(:layer_count) @name = args[:name] if args.key?(:name) @registry = args[:registry] if args.key?(:registry) @repository = args[:repository] if args.key?(:repository) end |