Class: Google::Apis::OndemandscanningV1::GrafeasV1BaseImage
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::GrafeasV1BaseImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
BaseImage describes a base image of a container image.
Instance Attribute Summary collapse
-
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
-
#name ⇒ String
The name of the base image.
-
#registry ⇒ String
The registry in which the base image is from.
-
#repository ⇒ String
The repository name in which the base image is from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1BaseImage
constructor
A new instance of GrafeasV1BaseImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1BaseImage
Returns a new instance of GrafeasV1BaseImage.
1457 1458 1459 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1457 def initialize(**args) update!(**args) end |
Instance Attribute Details
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
Corresponds to the JSON property layerCount
1440 1441 1442 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1440 def layer_count @layer_count end |
#name ⇒ String
The name of the base image.
Corresponds to the JSON property name
1445 1446 1447 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1445 def name @name end |
#registry ⇒ String
The registry in which the base image is from.
Corresponds to the JSON property registry
1450 1451 1452 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1450 def registry @registry end |
#repository ⇒ String
The repository name in which the base image is from.
Corresponds to the JSON property repository
1455 1456 1457 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1455 def repository @repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1462 1463 1464 1465 1466 1467 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1462 def update!(**args) @layer_count = args[:layer_count] if args.key?(:layer_count) @name = args[:name] if args.key?(:name) @registry = args[:registry] if args.key?(:registry) @repository = args[:repository] if args.key?(:repository) end |