Class: Google::Apis::OndemandscanningV1::GrafeasV1BaseImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

BaseImage describes a base image of a container image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1BaseImage

Returns a new instance of GrafeasV1BaseImage.



1376
1377
1378
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1376

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#layer_countFixnum

The number of layers that the base image is composed of. Corresponds to the JSON property layerCount

Returns:

  • (Fixnum)


1359
1360
1361
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1359

def layer_count
  @layer_count
end

#nameString

The name of the base image. Corresponds to the JSON property name

Returns:

  • (String)


1364
1365
1366
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1364

def name
  @name
end

#registryString

The registry in which the base image is from. Corresponds to the JSON property registry

Returns:

  • (String)


1369
1370
1371
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1369

def registry
  @registry
end

#repositoryString

The repository name in which the base image is from. Corresponds to the JSON property repository

Returns:

  • (String)


1374
1375
1376
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1374

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1381
1382
1383
1384
1385
1386
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1381

def update!(**args)
  @layer_count = args[:layer_count] if args.key?(:layer_count)
  @name = args[:name] if args.key?(:name)
  @registry = args[:registry] if args.key?(:registry)
  @repository = args[:repository] if args.key?(:repository)
end