Class: Google::Apis::OndemandscanningV1::GrafeasV1BaseImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

BaseImage describes a base image of a container image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1BaseImage

Returns a new instance of GrafeasV1BaseImage.



1359
1360
1361
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#layer_countFixnum

The number of layers that the base image is composed of. Corresponds to the JSON property layerCount

Returns:

  • (Fixnum)


1347
1348
1349
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1347

def layer_count
  @layer_count
end

#nameString

The name of the base image. Corresponds to the JSON property name

Returns:

  • (String)


1352
1353
1354
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1352

def name
  @name
end

#repositoryString

The repository name in which the base image is from. Corresponds to the JSON property repository

Returns:

  • (String)


1357
1358
1359
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1357

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1364
1365
1366
1367
1368
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1364

def update!(**args)
  @layer_count = args[:layer_count] if args.key?(:layer_count)
  @name = args[:name] if args.key?(:name)
  @repository = args[:repository] if args.key?(:repository)
end