Class: Google::Apis::OndemandscanningV1::GrafeasV1FileLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Indicates the location at which a package was found.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1FileLocation

Returns a new instance of GrafeasV1FileLocation.



1565
1566
1567
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_pathString

For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file. Corresponds to the JSON property filePath

Returns:

  • (String)


1552
1553
1554
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1552

def file_path
  @file_path
end

#layer_detailsGoogle::Apis::OndemandscanningV1::GrafeasV1LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



1557
1558
1559
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1557

def layer_details
  @layer_details
end

#line_numberFixnum

Line number in the file where the package was found. Optional field that only applies to source repository scanning. Corresponds to the JSON property lineNumber

Returns:

  • (Fixnum)


1563
1564
1565
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1563

def line_number
  @line_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1570
1571
1572
1573
1574
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1570

def update!(**args)
  @file_path = args[:file_path] if args.key?(:file_path)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
  @line_number = args[:line_number] if args.key?(:line_number)
end