Class: Google::Apis::OndemandscanningV1::GrafeasV1FileLocation
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::GrafeasV1FileLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Indicates the location at which a package was found.
Instance Attribute Summary collapse
-
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file.
-
#layer_details ⇒ Google::Apis::OndemandscanningV1::GrafeasV1LayerDetails
Details about the layer a package was found in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1FileLocation
constructor
A new instance of GrafeasV1FileLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1FileLocation
Returns a new instance of GrafeasV1FileLocation.
1386 1387 1388 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1386 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the
path to war file combined with the path to jar file.
Corresponds to the JSON property filePath
1379 1380 1381 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1379 def file_path @file_path end |
#layer_details ⇒ Google::Apis::OndemandscanningV1::GrafeasV1LayerDetails
Details about the layer a package was found in.
Corresponds to the JSON property layerDetails
1384 1385 1386 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1384 def layer_details @layer_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1391 1392 1393 1394 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1391 def update!(**args) @file_path = args[:file_path] if args.key?(:file_path) @layer_details = args[:layer_details] if args.key?(:layer_details) end |