Class: Google::Apis::OndemandscanningV1::GrafeasV1LayerDetails
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::GrafeasV1LayerDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Details about the layer a package was found in.
Instance Attribute Summary collapse
-
#base_images ⇒ Array<Google::Apis::OndemandscanningV1::GrafeasV1BaseImage>
The base images the layer is found within.
-
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image.
-
#command ⇒ String
The layer build command that was used to build the layer.
-
#diff_id ⇒ String
The diff ID (typically a sha256 hash) of the layer in the container image.
-
#index ⇒ Fixnum
The index of the layer in the container image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1LayerDetails
constructor
A new instance of GrafeasV1LayerDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1LayerDetails
Returns a new instance of GrafeasV1LayerDetails.
1608 1609 1610 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_images ⇒ Array<Google::Apis::OndemandscanningV1::GrafeasV1BaseImage>
The base images the layer is found within.
Corresponds to the JSON property baseImages
1584 1585 1586 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1584 def base_images @base_images end |
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image. https://
github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid
Corresponds to the JSON property chainId
1590 1591 1592 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1590 def chain_id @chain_id end |
#command ⇒ String
The layer build command that was used to build the layer. This may not be
found in all layers depending on how the container image is built.
Corresponds to the JSON property command
1596 1597 1598 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1596 def command @command end |
#diff_id ⇒ String
The diff ID (typically a sha256 hash) of the layer in the container image.
Corresponds to the JSON property diffId
1601 1602 1603 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1601 def diff_id @diff_id end |
#index ⇒ Fixnum
The index of the layer in the container image.
Corresponds to the JSON property index
1606 1607 1608 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1606 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1613 1614 1615 1616 1617 1618 1619 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1613 def update!(**args) @base_images = args[:base_images] if args.key?(:base_images) @chain_id = args[:chain_id] if args.key?(:chain_id) @command = args[:command] if args.key?(:command) @diff_id = args[:diff_id] if args.key?(:diff_id) @index = args[:index] if args.key?(:index) end |