Class: Google::Apis::OndemandscanningV1::GrafeasV1LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1LayerDetails

Returns a new instance of GrafeasV1LayerDetails.



1534
1535
1536
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1534

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::OndemandscanningV1::GrafeasV1BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



1510
1511
1512
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1510

def base_images
  @base_images
end

#chain_idString

The layer chain ID (sha256 hash) of the layer in the container image. https:// github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid Corresponds to the JSON property chainId

Returns:

  • (String)


1516
1517
1518
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1516

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


1522
1523
1524
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1522

def command
  @command
end

#diff_idString

The diff ID (typically a sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


1527
1528
1529
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1527

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


1532
1533
1534
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1532

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1539
1540
1541
1542
1543
1544
1545
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1539

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end