Class: Google::Apis::OndemandscanningV1::GrafeasV1LayerDetails
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::GrafeasV1LayerDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Details about the layer a package was found in.
Instance Attribute Summary collapse
-
#base_images ⇒ Array<Google::Apis::OndemandscanningV1::GrafeasV1BaseImage>
The base images the layer is found within.
-
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image.
-
#command ⇒ String
The layer build command that was used to build the layer.
-
#diff_id ⇒ String
The diff ID (typically a sha256 hash) of the layer in the container image.
-
#index ⇒ Fixnum
The index of the layer in the container image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1LayerDetails
constructor
A new instance of GrafeasV1LayerDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1LayerDetails
Returns a new instance of GrafeasV1LayerDetails.
1446 1447 1448 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_images ⇒ Array<Google::Apis::OndemandscanningV1::GrafeasV1BaseImage>
The base images the layer is found within.
Corresponds to the JSON property baseImages
1422 1423 1424 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1422 def base_images @base_images end |
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image. https://
github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid
Corresponds to the JSON property chainId
1428 1429 1430 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1428 def chain_id @chain_id end |
#command ⇒ String
The layer build command that was used to build the layer. This may not be
found in all layers depending on how the container image is built.
Corresponds to the JSON property command
1434 1435 1436 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1434 def command @command end |
#diff_id ⇒ String
The diff ID (typically a sha256 hash) of the layer in the container image.
Corresponds to the JSON property diffId
1439 1440 1441 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1439 def diff_id @diff_id end |
#index ⇒ Fixnum
The index of the layer in the container image.
Corresponds to the JSON property index
1444 1445 1446 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1444 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1451 1452 1453 1454 1455 1456 1457 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1451 def update!(**args) @base_images = args[:base_images] if args.key?(:base_images) @chain_id = args[:chain_id] if args.key?(:chain_id) @command = args[:command] if args.key?(:command) @diff_id = args[:diff_id] if args.key?(:diff_id) @index = args[:index] if args.key?(:index) end |