Class: Google::Apis::OndemandscanningV1::GrafeasV1LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1LayerDetails

Returns a new instance of GrafeasV1LayerDetails.



1428
1429
1430
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::OndemandscanningV1::GrafeasV1BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



1404
1405
1406
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1404

def base_images
  @base_images
end

#chain_idString

The layer chain ID (sha256 hash) of the layer in the container image. https:// github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid Corresponds to the JSON property chainId

Returns:

  • (String)


1410
1411
1412
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1410

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


1416
1417
1418
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1416

def command
  @command
end

#diff_idString

The diff ID (typically a sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


1421
1422
1423
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1421

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


1426
1427
1428
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1426

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1433
1434
1435
1436
1437
1438
1439
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1433

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end