Class: Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder.



1632
1633
1634
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Corresponds to the JSON property id

Returns:

  • (String)


1630
1631
1632
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1630

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1637
1638
1639
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1637

def update!(**args)
  @id = args[:id] if args.key?(:id)
end