Class: Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder.



1558
1559
1560
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Corresponds to the JSON property id

Returns:

  • (String)


1556
1557
1558
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1556

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1563
1564
1565
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1563

def update!(**args)
  @id = args[:id] if args.key?(:id)
end