Class: Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder.



1470
1471
1472
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Corresponds to the JSON property id

Returns:

  • (String)


1468
1469
1470
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1468

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1475
1476
1477
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1475

def update!(**args)
  @id = args[:id] if args.key?(:id)
end