Class: Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Describes where the config file that kicked off the build came from. This is effectively a pointer to the source where buildConfig came from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource.



1517
1518
1519
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


1505
1506
1507
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1505

def digest
  @digest
end

#entry_pointString

Corresponds to the JSON property entryPoint

Returns:

  • (String)


1510
1511
1512
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1510

def entry_point
  @entry_point
end

#uriString

Corresponds to the JSON property uri

Returns:

  • (String)


1515
1516
1517
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1515

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1522
1523
1524
1525
1526
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1522

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @entry_point = args[:entry_point] if args.key?(:entry_point)
  @uri = args[:uri] if args.key?(:uri)
end