Class: Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial.



1682
1683
1684
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


1675
1676
1677
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1675

def digest
  @digest
end

#uriString

Corresponds to the JSON property uri

Returns:

  • (String)


1680
1681
1682
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1680

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1687
1688
1689
1690
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1687

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @uri = args[:uri] if args.key?(:uri)
end