Class: Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial.



1576
1577
1578
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1576

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


1569
1570
1571
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1569

def digest
  @digest
end

#uriString

Corresponds to the JSON property uri

Returns:

  • (String)


1574
1575
1576
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1574

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1581
1582
1583
1584
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1581

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @uri = args[:uri] if args.key?(:uri)
end