Class: Google::Apis::OndemandscanningV1::InTotoProvenance
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::InTotoProvenance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Instance Attribute Summary collapse
-
#builder_config ⇒ Google::Apis::OndemandscanningV1::BuilderConfig
required Corresponds to the JSON property
builderConfig. -
#materials ⇒ Array<String>
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
-
#metadata ⇒ Google::Apis::OndemandscanningV1::Metadata
Other properties of the build.
-
#recipe ⇒ Google::Apis::OndemandscanningV1::Recipe
Steps taken to build the artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InTotoProvenance
constructor
A new instance of InTotoProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InTotoProvenance
Returns a new instance of InTotoProvenance.
1932 1933 1934 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#builder_config ⇒ Google::Apis::OndemandscanningV1::BuilderConfig
required
Corresponds to the JSON property builderConfig
1911 1912 1913 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1911 def builder_config @builder_config end |
#materials ⇒ Array<String>
The collection of artifacts that influenced the build including sources,
dependencies, build tools, base images, and so on. This is considered to be
incomplete unless metadata.completeness.materials is true. Unset or null is
equivalent to empty.
Corresponds to the JSON property materials
1919 1920 1921 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1919 def materials @materials end |
#metadata ⇒ Google::Apis::OndemandscanningV1::Metadata
Other properties of the build.
Corresponds to the JSON property metadata
1924 1925 1926 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1924 def @metadata end |
#recipe ⇒ Google::Apis::OndemandscanningV1::Recipe
Steps taken to build the artifact. For a TaskRun, typically each container
corresponds to one step in the recipe.
Corresponds to the JSON property recipe
1930 1931 1932 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1930 def recipe @recipe end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1937 1938 1939 1940 1941 1942 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1937 def update!(**args) @builder_config = args[:builder_config] if args.key?(:builder_config) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) @recipe = args[:recipe] if args.key?(:recipe) end |