Class: Google::Apis::OndemandscanningV1::InTotoProvenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InTotoProvenance

Returns a new instance of InTotoProvenance.



1920
1921
1922
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1920

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builder_configGoogle::Apis::OndemandscanningV1::BuilderConfig

required Corresponds to the JSON property builderConfig



1899
1900
1901
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1899

def builder_config
  @builder_config
end

#materialsArray<String>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials

Returns:

  • (Array<String>)


1907
1908
1909
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1907

def materials
  @materials
end

#metadataGoogle::Apis::OndemandscanningV1::Metadata

Other properties of the build. Corresponds to the JSON property metadata



1912
1913
1914
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1912

def 
  @metadata
end

#recipeGoogle::Apis::OndemandscanningV1::Recipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



1918
1919
1920
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1918

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1925
1926
1927
1928
1929
1930
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1925

def update!(**args)
  @builder_config = args[:builder_config] if args.key?(:builder_config)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end