Class: Google::Apis::OndemandscanningV1::InTotoProvenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InTotoProvenance

Returns a new instance of InTotoProvenance.



1858
1859
1860
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builder_configGoogle::Apis::OndemandscanningV1::BuilderConfig

required Corresponds to the JSON property builderConfig



1837
1838
1839
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1837

def builder_config
  @builder_config
end

#materialsArray<String>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials

Returns:

  • (Array<String>)


1845
1846
1847
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1845

def materials
  @materials
end

#metadataGoogle::Apis::OndemandscanningV1::Metadata

Other properties of the build. Corresponds to the JSON property metadata



1850
1851
1852
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1850

def 
  @metadata
end

#recipeGoogle::Apis::OndemandscanningV1::Recipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



1856
1857
1858
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1856

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1863
1864
1865
1866
1867
1868
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1863

def update!(**args)
  @builder_config = args[:builder_config] if args.key?(:builder_config)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end