Class: Google::Apis::OndemandscanningV1::LayerDetails
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::LayerDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Details about the layer a package was found in.
Instance Attribute Summary collapse
-
#base_images ⇒ Array<Google::Apis::OndemandscanningV1::BaseImage>
The base images the layer is found within.
-
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image.
-
#command ⇒ String
The layer build command that was used to build the layer.
-
#diff_id ⇒ String
The diff ID (sha256 hash) of the layer in the container image.
-
#index ⇒ Fixnum
The index of the layer in the container image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LayerDetails
constructor
A new instance of LayerDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LayerDetails
Returns a new instance of LayerDetails.
2160 2161 2162 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_images ⇒ Array<Google::Apis::OndemandscanningV1::BaseImage>
The base images the layer is found within.
Corresponds to the JSON property baseImages
2136 2137 2138 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2136 def base_images @base_images end |
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image. https://
github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid
Corresponds to the JSON property chainId
2142 2143 2144 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2142 def chain_id @chain_id end |
#command ⇒ String
The layer build command that was used to build the layer. This may not be
found in all layers depending on how the container image is built.
Corresponds to the JSON property command
2148 2149 2150 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2148 def command @command end |
#diff_id ⇒ String
The diff ID (sha256 hash) of the layer in the container image.
Corresponds to the JSON property diffId
2153 2154 2155 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2153 def diff_id @diff_id end |
#index ⇒ Fixnum
The index of the layer in the container image.
Corresponds to the JSON property index
2158 2159 2160 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2158 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2165 2166 2167 2168 2169 2170 2171 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2165 def update!(**args) @base_images = args[:base_images] if args.key?(:base_images) @chain_id = args[:chain_id] if args.key?(:chain_id) @command = args[:command] if args.key?(:command) @diff_id = args[:diff_id] if args.key?(:diff_id) @index = args[:index] if args.key?(:index) end |