Class: Google::Apis::OndemandscanningV1::LayerDetails
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::LayerDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Details about the layer a package was found in.
Instance Attribute Summary collapse
-
#base_images ⇒ Array<Google::Apis::OndemandscanningV1::BaseImage>
The base images the layer is found within.
-
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image.
-
#command ⇒ String
The layer build command that was used to build the layer.
-
#diff_id ⇒ String
The diff ID (sha256 hash) of the layer in the container image.
-
#index ⇒ Fixnum
The index of the layer in the container image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LayerDetails
constructor
A new instance of LayerDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LayerDetails
Returns a new instance of LayerDetails.
2100 2101 2102 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_images ⇒ Array<Google::Apis::OndemandscanningV1::BaseImage>
The base images the layer is found within.
Corresponds to the JSON property baseImages
2076 2077 2078 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2076 def base_images @base_images end |
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image. https://
github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid
Corresponds to the JSON property chainId
2082 2083 2084 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2082 def chain_id @chain_id end |
#command ⇒ String
The layer build command that was used to build the layer. This may not be
found in all layers depending on how the container image is built.
Corresponds to the JSON property command
2088 2089 2090 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2088 def command @command end |
#diff_id ⇒ String
The diff ID (sha256 hash) of the layer in the container image.
Corresponds to the JSON property diffId
2093 2094 2095 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2093 def diff_id @diff_id end |
#index ⇒ Fixnum
The index of the layer in the container image.
Corresponds to the JSON property index
2098 2099 2100 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2098 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2105 2106 2107 2108 2109 2110 2111 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2105 def update!(**args) @base_images = args[:base_images] if args.key?(:base_images) @chain_id = args[:chain_id] if args.key?(:chain_id) @command = args[:command] if args.key?(:command) @diff_id = args[:diff_id] if args.key?(:diff_id) @index = args[:index] if args.key?(:index) end |