Class: Google::Apis::OndemandscanningV1::LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LayerDetails

Returns a new instance of LayerDetails.



2092
2093
2094
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::OndemandscanningV1::BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



2068
2069
2070
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2068

def base_images
  @base_images
end

#chain_idString

The layer chain ID (sha256 hash) of the layer in the container image. https:// github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid Corresponds to the JSON property chainId

Returns:

  • (String)


2074
2075
2076
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2074

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


2080
2081
2082
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2080

def command
  @command
end

#diff_idString

The diff ID (sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


2085
2086
2087
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2085

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


2090
2091
2092
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2090

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2097
2098
2099
2100
2101
2102
2103
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2097

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end