Class: Google::Apis::OndemandscanningV1::LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LayerDetails

Returns a new instance of LayerDetails.



2004
2005
2006
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::OndemandscanningV1::BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



1980
1981
1982
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1980

def base_images
  @base_images
end

#chain_idString

The layer chain ID (sha256 hash) of the layer in the container image. https:// github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid Corresponds to the JSON property chainId

Returns:

  • (String)


1986
1987
1988
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1986

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


1992
1993
1994
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1992

def command
  @command
end

#diff_idString

The diff ID (sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


1997
1998
1999
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1997

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


2002
2003
2004
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2002

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2009
2010
2011
2012
2013
2014
2015
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2009

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end