Class: Google::Apis::OndemandscanningV1::LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LayerDetails

Returns a new instance of LayerDetails.



1986
1987
1988
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1986

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::OndemandscanningV1::BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



1962
1963
1964
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1962

def base_images
  @base_images
end

#chain_idString

The layer chain ID (sha256 hash) of the layer in the container image. https:// github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid Corresponds to the JSON property chainId

Returns:

  • (String)


1968
1969
1970
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1968

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


1974
1975
1976
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1974

def command
  @command
end

#diff_idString

The diff ID (sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


1979
1980
1981
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1979

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


1984
1985
1986
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1984

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1991
1992
1993
1994
1995
1996
1997
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 1991

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end