Class: Google::Apis::OndemandscanningV1::Occurrence
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::Occurrence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
An instance of an analysis type that has been found on a resource.
Instance Attribute Summary collapse
-
#advisory_publish_time ⇒ String
The time this advisory was published by the source.
-
#ai_skill_analysis ⇒ Google::Apis::OndemandscanningV1::AiSkillAnalysisOccurrence
AISkillAnalysisOccurrence provides the results of an AI-based skill analysis.
-
#attestation ⇒ Google::Apis::OndemandscanningV1::AttestationOccurrence
Occurrence that represents a single "attestation".
-
#build ⇒ Google::Apis::OndemandscanningV1::BuildOccurrence
Details of a build occurrence.
-
#compliance ⇒ Google::Apis::OndemandscanningV1::ComplianceOccurrence
An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason.
-
#create_time ⇒ String
Output only.
-
#deployment ⇒ Google::Apis::OndemandscanningV1::DeploymentOccurrence
The period during which some deployable was active in a runtime.
-
#discovery ⇒ Google::Apis::OndemandscanningV1::DiscoveryOccurrence
Provides information about the analysis status of a discovered resource.
-
#dsse_attestation ⇒ Google::Apis::OndemandscanningV1::DsseAttestationOccurrence
Deprecated.
- #envelope ⇒ Google::Apis::OndemandscanningV1::Envelope
-
#image ⇒ Google::Apis::OndemandscanningV1::ImageOccurrence
Details of the derived image portion of the DockerImage relationship.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#note_name ⇒ String
Required.
-
#package ⇒ Google::Apis::OndemandscanningV1::PackageOccurrence
Details on how a particular software package was installed on a system.
-
#remediation ⇒ String
A description of actions that can be taken to remedy the note.
-
#resource_uri ⇒ String
Required.
-
#sbom_reference ⇒ Google::Apis::OndemandscanningV1::SbomReferenceOccurrence
The occurrence representing an SBOM reference as applied to a specific resource.
-
#secret ⇒ Google::Apis::OndemandscanningV1::SecretOccurrence
The occurrence provides details of a secret.
-
#update_time ⇒ String
Output only.
-
#upgrade ⇒ Google::Apis::OndemandscanningV1::UpgradeOccurrence
An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade.
-
#vulnerability ⇒ Google::Apis::OndemandscanningV1::VulnerabilityOccurrence
An occurrence of a severity vulnerability on a resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Occurrence
constructor
A new instance of Occurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Occurrence
Returns a new instance of Occurrence.
2612 2613 2614 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2612 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advisory_publish_time ⇒ String
The time this advisory was published by the source.
Corresponds to the JSON property advisoryPublishTime
2483 2484 2485 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2483 def advisory_publish_time @advisory_publish_time end |
#ai_skill_analysis ⇒ Google::Apis::OndemandscanningV1::AiSkillAnalysisOccurrence
AISkillAnalysisOccurrence provides the results of an AI-based skill analysis.
Corresponds to the JSON property aiSkillAnalysis
2488 2489 2490 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2488 def ai_skill_analysis @ai_skill_analysis end |
#attestation ⇒ Google::Apis::OndemandscanningV1::AttestationOccurrence
Occurrence that represents a single "attestation". The authenticity of an
attestation can be verified using the attached signature. If the verifier
trusts the public key of the signer, then verifying the signature is
sufficient to establish trust. In this circumstance, the authority to which
this attestation is attached is primarily useful for lookup (how to find this
attestation if you already know the authority and artifact to be verified) and
intent (for which authority this attestation was intended to sign.
Corresponds to the JSON property attestation
2499 2500 2501 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2499 def attestation @attestation end |
#build ⇒ Google::Apis::OndemandscanningV1::BuildOccurrence
Details of a build occurrence.
Corresponds to the JSON property build
2504 2505 2506 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2504 def build @build end |
#compliance ⇒ Google::Apis::OndemandscanningV1::ComplianceOccurrence
An indication that the compliance checks in the associated ComplianceNote were
not satisfied for particular resources or a specified reason.
Corresponds to the JSON property compliance
2510 2511 2512 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2510 def compliance @compliance end |
#create_time ⇒ String
Output only. The time this occurrence was created.
Corresponds to the JSON property createTime
2515 2516 2517 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2515 def create_time @create_time end |
#deployment ⇒ Google::Apis::OndemandscanningV1::DeploymentOccurrence
The period during which some deployable was active in a runtime.
Corresponds to the JSON property deployment
2520 2521 2522 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2520 def deployment @deployment end |
#discovery ⇒ Google::Apis::OndemandscanningV1::DiscoveryOccurrence
Provides information about the analysis status of a discovered resource.
Corresponds to the JSON property discovery
2525 2526 2527 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2525 def discovery @discovery end |
#dsse_attestation ⇒ Google::Apis::OndemandscanningV1::DsseAttestationOccurrence
Deprecated. Prefer to use a regular Occurrence, and populate the Envelope at
the top level of the Occurrence.
Corresponds to the JSON property dsseAttestation
2531 2532 2533 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2531 def dsse_attestation @dsse_attestation end |
#envelope ⇒ Google::Apis::OndemandscanningV1::Envelope
MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope.
proto. An authenticated message of arbitrary type.
Corresponds to the JSON property envelope
2537 2538 2539 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2537 def envelope @envelope end |
#image ⇒ Google::Apis::OndemandscanningV1::ImageOccurrence
Details of the derived image portion of the DockerImage relationship. This
image would be produced from a Dockerfile with FROM .
Corresponds to the JSON property image
2543 2544 2545 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2543 def image @image end |
#kind ⇒ String
Output only. This explicitly denotes which of the occurrence details are
specified. This field can be used as a filter in list requests.
Corresponds to the JSON property kind
2549 2550 2551 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2549 def kind @kind end |
#name ⇒ String
Output only. The name of the occurrence in the form of projects/[PROJECT_ID]/
occurrences/[OCCURRENCE_ID].
Corresponds to the JSON property name
2555 2556 2557 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2555 def name @name end |
#note_name ⇒ String
Required. Immutable. The analysis note associated with this occurrence, in the
form of projects/[PROVIDER_ID]/notes/[NOTE_ID]. This field can be used as a
filter in list requests.
Corresponds to the JSON property noteName
2562 2563 2564 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2562 def note_name @note_name end |
#package ⇒ Google::Apis::OndemandscanningV1::PackageOccurrence
Details on how a particular software package was installed on a system.
Corresponds to the JSON property package
2567 2568 2569 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2567 def package @package end |
#remediation ⇒ String
A description of actions that can be taken to remedy the note.
Corresponds to the JSON property remediation
2572 2573 2574 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2572 def remediation @remediation end |
#resource_uri ⇒ String
Required. Immutable. A URI that represents the resource for which the
occurrence applies. For example, https://gcr.io/project/image@sha256:123abc
for a Docker image.
Corresponds to the JSON property resourceUri
2579 2580 2581 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2579 def resource_uri @resource_uri end |
#sbom_reference ⇒ Google::Apis::OndemandscanningV1::SbomReferenceOccurrence
The occurrence representing an SBOM reference as applied to a specific
resource. The occurrence follows the DSSE specification. See https://github.
com/secure-systems-lab/dsse/blob/master/envelope.md for more details.
Corresponds to the JSON property sbomReference
2586 2587 2588 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2586 def sbom_reference @sbom_reference end |
#secret ⇒ Google::Apis::OndemandscanningV1::SecretOccurrence
The occurrence provides details of a secret.
Corresponds to the JSON property secret
2591 2592 2593 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2591 def secret @secret end |
#update_time ⇒ String
Output only. The time this occurrence was last updated.
Corresponds to the JSON property updateTime
2596 2597 2598 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2596 def update_time @update_time end |
#upgrade ⇒ Google::Apis::OndemandscanningV1::UpgradeOccurrence
An Upgrade Occurrence represents that a specific resource_url could install a
specific upgrade. This presence is supplied via local sources (i.e. it is
present in the mirror and the running system has noticed its availability).
For Windows, both distribution and windows_update contain information for the
Windows update.
Corresponds to the JSON property upgrade
2605 2606 2607 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2605 def upgrade @upgrade end |
#vulnerability ⇒ Google::Apis::OndemandscanningV1::VulnerabilityOccurrence
An occurrence of a severity vulnerability on a resource.
Corresponds to the JSON property vulnerability
2610 2611 2612 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2610 def vulnerability @vulnerability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2617 def update!(**args) @advisory_publish_time = args[:advisory_publish_time] if args.key?(:advisory_publish_time) @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis) @attestation = args[:attestation] if args.key?(:attestation) @build = args[:build] if args.key?(:build) @compliance = args[:compliance] if args.key?(:compliance) @create_time = args[:create_time] if args.key?(:create_time) @deployment = args[:deployment] if args.key?(:deployment) @discovery = args[:discovery] if args.key?(:discovery) @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation) @envelope = args[:envelope] if args.key?(:envelope) @image = args[:image] if args.key?(:image) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @note_name = args[:note_name] if args.key?(:note_name) @package = args[:package] if args.key?(:package) @remediation = args[:remediation] if args.key?(:remediation) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference) @secret = args[:secret] if args.key?(:secret) @update_time = args[:update_time] if args.key?(:update_time) @upgrade = args[:upgrade] if args.key?(:upgrade) @vulnerability = args[:vulnerability] if args.key?(:vulnerability) end |