Class: Google::Apis::OndemandscanningV1::PackageData
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::PackageData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the package.
-
#binary_source_info ⇒ Array<Google::Apis::OndemandscanningV1::BinarySourceInfo>
A bundle containing the binary and source information.
-
#binary_version ⇒ Google::Apis::OndemandscanningV1::PackageVersion
DEPRECATED Corresponds to the JSON property
binaryVersion. -
#cpe_uri ⇒ String
The cpe_uri in cpe format in which the vulnerability may manifest.
-
#dependency_chain ⇒ Array<Google::Apis::OndemandscanningV1::LanguagePackageDependency>
The dependency chain between this package and the user's artifact.
-
#file_location ⇒ Array<Google::Apis::OndemandscanningV1::FileLocation>
The path to the jar file / go binary file.
-
#hash_digest ⇒ String
HashDigest stores the SHA512 hash digest of the jar file if the package is of type Maven.
-
#layer_details ⇒ Google::Apis::OndemandscanningV1::LayerDetails
Details about the layer a package was found in.
-
#licenses ⇒ Array<String>
The list of licenses found that are related to a given package.
-
#maintainer ⇒ Google::Apis::OndemandscanningV1::Maintainer
The maintainer of the package.
-
#os ⇒ String
The OS affected by a vulnerability Used to generate the cpe_uri for OS packages Corresponds to the JSON property
os. -
#os_version ⇒ String
The version of the OS Used to generate the cpe_uri for OS packages Corresponds to the JSON property
osVersion. -
#package ⇒ String
The package being analysed for vulnerabilities Corresponds to the JSON property
package. -
#package_type ⇒ String
The type of package: os, maven, go, etc.
-
#patched_cve ⇒ Array<String>
CVEs that this package is no longer vulnerable to Corresponds to the JSON property
patchedCve. -
#source_version ⇒ Google::Apis::OndemandscanningV1::PackageVersion
DEPRECATED Corresponds to the JSON property
sourceVersion. -
#unused ⇒ String
Corresponds to the JSON property
unused. -
#version ⇒ String
The version of the package being analysed Corresponds to the JSON property
version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageData
constructor
A new instance of PackageData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageData
Returns a new instance of PackageData.
2704 2705 2706 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2704 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
The architecture of the package.
Corresponds to the JSON property architecture
2607 2608 2609 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2607 def architecture @architecture end |
#binary_source_info ⇒ Array<Google::Apis::OndemandscanningV1::BinarySourceInfo>
A bundle containing the binary and source information.
Corresponds to the JSON property binarySourceInfo
2612 2613 2614 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2612 def binary_source_info @binary_source_info end |
#binary_version ⇒ Google::Apis::OndemandscanningV1::PackageVersion
DEPRECATED
Corresponds to the JSON property binaryVersion
2617 2618 2619 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2617 def binary_version @binary_version end |
#cpe_uri ⇒ String
The cpe_uri in cpe format in which
the vulnerability may manifest. Examples include distro or storage location
for vulnerable jar.
Corresponds to the JSON property cpeUri
2624 2625 2626 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2624 def cpe_uri @cpe_uri end |
#dependency_chain ⇒ Array<Google::Apis::OndemandscanningV1::LanguagePackageDependency>
The dependency chain between this package and the user's artifact. List in
order from the customer's package under review first, to the current package
last. Inclusive of the original package and the current package.
Corresponds to the JSON property dependencyChain
2631 2632 2633 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2631 def dependency_chain @dependency_chain end |
#file_location ⇒ Array<Google::Apis::OndemandscanningV1::FileLocation>
The path to the jar file / go binary file.
Corresponds to the JSON property fileLocation
2636 2637 2638 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2636 def file_location @file_location end |
#hash_digest ⇒ String
HashDigest stores the SHA512 hash digest of the jar file if the package is of
type Maven. This field will be unset for non Maven packages.
Corresponds to the JSON property hashDigest
2642 2643 2644 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2642 def hash_digest @hash_digest end |
#layer_details ⇒ Google::Apis::OndemandscanningV1::LayerDetails
Details about the layer a package was found in.
Corresponds to the JSON property layerDetails
2647 2648 2649 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2647 def layer_details @layer_details end |
#licenses ⇒ Array<String>
The list of licenses found that are related to a given package. Note that
licenses may also be stored on the BinarySourceInfo. If there is no
BinarySourceInfo (because there's no concept of source vs binary), then it
will be stored here, while if there are BinarySourceInfos, it will be stored
there, as one source can have multiple binaries with different licenses.
Corresponds to the JSON property licenses
2656 2657 2658 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2656 def licenses @licenses end |
#maintainer ⇒ Google::Apis::OndemandscanningV1::Maintainer
The maintainer of the package.
Corresponds to the JSON property maintainer
2661 2662 2663 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2661 def maintainer @maintainer end |
#os ⇒ String
The OS affected by a vulnerability Used to generate the cpe_uri for OS
packages
Corresponds to the JSON property os
2667 2668 2669 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2667 def os @os end |
#os_version ⇒ String
The version of the OS Used to generate the cpe_uri for OS packages
Corresponds to the JSON property osVersion
2672 2673 2674 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2672 def os_version @os_version end |
#package ⇒ String
The package being analysed for vulnerabilities
Corresponds to the JSON property package
2677 2678 2679 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2677 def package @package end |
#package_type ⇒ String
The type of package: os, maven, go, etc.
Corresponds to the JSON property packageType
2682 2683 2684 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2682 def package_type @package_type end |
#patched_cve ⇒ Array<String>
CVEs that this package is no longer vulnerable to
Corresponds to the JSON property patchedCve
2687 2688 2689 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2687 def patched_cve @patched_cve end |
#source_version ⇒ Google::Apis::OndemandscanningV1::PackageVersion
DEPRECATED
Corresponds to the JSON property sourceVersion
2692 2693 2694 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2692 def source_version @source_version end |
#unused ⇒ String
Corresponds to the JSON property unused
2697 2698 2699 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2697 def unused @unused end |
#version ⇒ String
The version of the package being analysed
Corresponds to the JSON property version
2702 2703 2704 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2702 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2709 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @binary_source_info = args[:binary_source_info] if args.key?(:binary_source_info) @binary_version = args[:binary_version] if args.key?(:binary_version) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @dependency_chain = args[:dependency_chain] if args.key?(:dependency_chain) @file_location = args[:file_location] if args.key?(:file_location) @hash_digest = args[:hash_digest] if args.key?(:hash_digest) @layer_details = args[:layer_details] if args.key?(:layer_details) @licenses = args[:licenses] if args.key?(:licenses) @maintainer = args[:maintainer] if args.key?(:maintainer) @os = args[:os] if args.key?(:os) @os_version = args[:os_version] if args.key?(:os_version) @package = args[:package] if args.key?(:package) @package_type = args[:package_type] if args.key?(:package_type) @patched_cve = args[:patched_cve] if args.key?(:patched_cve) @source_version = args[:source_version] if args.key?(:source_version) @unused = args[:unused] if args.key?(:unused) @version = args[:version] if args.key?(:version) end |