Class: Google::Apis::OndemandscanningV1::PackageData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageData

Returns a new instance of PackageData.



2586
2587
2588
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The architecture of the package. Corresponds to the JSON property architecture

Returns:

  • (String)


2489
2490
2491
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2489

def architecture
  @architecture
end

#binary_source_infoArray<Google::Apis::OndemandscanningV1::BinarySourceInfo>

A bundle containing the binary and source information. Corresponds to the JSON property binarySourceInfo



2494
2495
2496
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2494

def binary_source_info
  @binary_source_info
end

#binary_versionGoogle::Apis::OndemandscanningV1::PackageVersion

DEPRECATED Corresponds to the JSON property binaryVersion



2499
2500
2501
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2499

def binary_version
  @binary_version
end

#cpe_uriString

The cpe_uri in cpe format in which the vulnerability may manifest. Examples include distro or storage location for vulnerable jar. Corresponds to the JSON property cpeUri

Returns:

  • (String)


2506
2507
2508
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2506

def cpe_uri
  @cpe_uri
end

#dependency_chainArray<Google::Apis::OndemandscanningV1::LanguagePackageDependency>

The dependency chain between this package and the user's artifact. List in order from the customer's package under review first, to the current package last. Inclusive of the original package and the current package. Corresponds to the JSON property dependencyChain



2513
2514
2515
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2513

def dependency_chain
  @dependency_chain
end

#file_locationArray<Google::Apis::OndemandscanningV1::FileLocation>

The path to the jar file / go binary file. Corresponds to the JSON property fileLocation



2518
2519
2520
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2518

def file_location
  @file_location
end

#hash_digestString

HashDigest stores the SHA512 hash digest of the jar file if the package is of type Maven. This field will be unset for non Maven packages. Corresponds to the JSON property hashDigest

Returns:

  • (String)


2524
2525
2526
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2524

def hash_digest
  @hash_digest
end

#layer_detailsGoogle::Apis::OndemandscanningV1::LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



2529
2530
2531
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2529

def layer_details
  @layer_details
end

#licensesArray<String>

The list of licenses found that are related to a given package. Note that licenses may also be stored on the BinarySourceInfo. If there is no BinarySourceInfo (because there's no concept of source vs binary), then it will be stored here, while if there are BinarySourceInfos, it will be stored there, as one source can have multiple binaries with different licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


2538
2539
2540
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2538

def licenses
  @licenses
end

#maintainerGoogle::Apis::OndemandscanningV1::Maintainer

The maintainer of the package. Corresponds to the JSON property maintainer



2543
2544
2545
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2543

def maintainer
  @maintainer
end

#osString

The OS affected by a vulnerability Used to generate the cpe_uri for OS packages Corresponds to the JSON property os

Returns:

  • (String)


2549
2550
2551
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2549

def os
  @os
end

#os_versionString

The version of the OS Used to generate the cpe_uri for OS packages Corresponds to the JSON property osVersion

Returns:

  • (String)


2554
2555
2556
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2554

def os_version
  @os_version
end

#packageString

The package being analysed for vulnerabilities Corresponds to the JSON property package

Returns:

  • (String)


2559
2560
2561
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2559

def package
  @package
end

#package_typeString

The type of package: os, maven, go, etc. Corresponds to the JSON property packageType

Returns:

  • (String)


2564
2565
2566
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2564

def package_type
  @package_type
end

#patched_cveArray<String>

CVEs that this package is no longer vulnerable to Corresponds to the JSON property patchedCve

Returns:

  • (Array<String>)


2569
2570
2571
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2569

def patched_cve
  @patched_cve
end

#source_versionGoogle::Apis::OndemandscanningV1::PackageVersion

DEPRECATED Corresponds to the JSON property sourceVersion



2574
2575
2576
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2574

def source_version
  @source_version
end

#unusedString

Corresponds to the JSON property unused

Returns:

  • (String)


2579
2580
2581
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2579

def unused
  @unused
end

#versionString

The version of the package being analysed Corresponds to the JSON property version

Returns:

  • (String)


2584
2585
2586
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2584

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2591

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @binary_source_info = args[:binary_source_info] if args.key?(:binary_source_info)
  @binary_version = args[:binary_version] if args.key?(:binary_version)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @dependency_chain = args[:dependency_chain] if args.key?(:dependency_chain)
  @file_location = args[:file_location] if args.key?(:file_location)
  @hash_digest = args[:hash_digest] if args.key?(:hash_digest)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
  @licenses = args[:licenses] if args.key?(:licenses)
  @maintainer = args[:maintainer] if args.key?(:maintainer)
  @os = args[:os] if args.key?(:os)
  @os_version = args[:os_version] if args.key?(:os_version)
  @package = args[:package] if args.key?(:package)
  @package_type = args[:package_type] if args.key?(:package_type)
  @patched_cve = args[:patched_cve] if args.key?(:patched_cve)
  @source_version = args[:source_version] if args.key?(:source_version)
  @unused = args[:unused] if args.key?(:unused)
  @version = args[:version] if args.key?(:version)
end