Class: Google::Apis::OndemandscanningV1::PackageIssue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

A detail for a distro and package this vulnerability occurrence was found in and its associated fix (if one is available).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageIssue

Returns a new instance of PackageIssue.



2692
2693
2694
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2692

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_cpe_uriString

Required. The CPE URI this vulnerability was found in. Corresponds to the JSON property affectedCpeUri

Returns:

  • (String)


2640
2641
2642
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2640

def affected_cpe_uri
  @affected_cpe_uri
end

#affected_packageString

Required. The package this vulnerability was found in. Corresponds to the JSON property affectedPackage

Returns:

  • (String)


2645
2646
2647
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2645

def affected_package
  @affected_package
end

#affected_versionGoogle::Apis::OndemandscanningV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property affectedVersion



2650
2651
2652
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2650

def affected_version
  @affected_version
end

#effective_severityString

Output only. The distro or language system assigned severity for this vulnerability when that is available and note provider assigned severity when it is not available. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


2657
2658
2659
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2657

def effective_severity
  @effective_severity
end

#file_locationArray<Google::Apis::OndemandscanningV1::GrafeasV1FileLocation>

The location at which this package was found. Corresponds to the JSON property fileLocation



2662
2663
2664
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2662

def file_location
  @file_location
end

#fix_availableBoolean Also known as: fix_available?

Output only. Whether a fix is available for this package. Corresponds to the JSON property fixAvailable

Returns:

  • (Boolean)


2667
2668
2669
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2667

def fix_available
  @fix_available
end

#fixed_cpe_uriString

The CPE URI this vulnerability was fixed in. It is possible for this to be different from the affected_cpe_uri. Corresponds to the JSON property fixedCpeUri

Returns:

  • (String)


2674
2675
2676
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2674

def fixed_cpe_uri
  @fixed_cpe_uri
end

#fixed_packageString

The package this vulnerability was fixed in. It is possible for this to be different from the affected_package. Corresponds to the JSON property fixedPackage

Returns:

  • (String)


2680
2681
2682
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2680

def fixed_package
  @fixed_package
end

#fixed_versionGoogle::Apis::OndemandscanningV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property fixedVersion



2685
2686
2687
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2685

def fixed_version
  @fixed_version
end

#package_typeString

The type of package (e.g. OS, MAVEN, GO). Corresponds to the JSON property packageType

Returns:

  • (String)


2690
2691
2692
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2690

def package_type
  @package_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2697
2698
2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2697

def update!(**args)
  @affected_cpe_uri = args[:affected_cpe_uri] if args.key?(:affected_cpe_uri)
  @affected_package = args[:affected_package] if args.key?(:affected_package)
  @affected_version = args[:affected_version] if args.key?(:affected_version)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @file_location = args[:file_location] if args.key?(:file_location)
  @fix_available = args[:fix_available] if args.key?(:fix_available)
  @fixed_cpe_uri = args[:fixed_cpe_uri] if args.key?(:fixed_cpe_uri)
  @fixed_package = args[:fixed_package] if args.key?(:fixed_package)
  @fixed_version = args[:fixed_version] if args.key?(:fixed_version)
  @package_type = args[:package_type] if args.key?(:package_type)
end