Class: Google::Apis::OndemandscanningV1::PackageIssue
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::PackageIssue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
A detail for a distro and package this vulnerability occurrence was found in and its associated fix (if one is available).
Instance Attribute Summary collapse
-
#affected_cpe_uri ⇒ String
Required.
-
#affected_package ⇒ String
Required.
-
#affected_version ⇒ Google::Apis::OndemandscanningV1::Version
Version contains structured information about the version of a package.
-
#effective_severity ⇒ String
Output only.
-
#file_location ⇒ Array<Google::Apis::OndemandscanningV1::GrafeasV1FileLocation>
The location at which this package was found.
-
#fix_available ⇒ Boolean
(also: #fix_available?)
Output only.
-
#fixed_cpe_uri ⇒ String
The CPE URI this vulnerability was fixed in.
-
#fixed_package ⇒ String
The package this vulnerability was fixed in.
-
#fixed_version ⇒ Google::Apis::OndemandscanningV1::Version
Version contains structured information about the version of a package.
-
#package_type ⇒ String
The type of package (e.g. OS, MAVEN, GO).
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageIssue
constructor
A new instance of PackageIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageIssue
Returns a new instance of PackageIssue.
2674 2675 2676 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affected_cpe_uri ⇒ String
Required. The CPE URI this
vulnerability was found in.
Corresponds to the JSON property affectedCpeUri
2622 2623 2624 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2622 def affected_cpe_uri @affected_cpe_uri end |
#affected_package ⇒ String
Required. The package this vulnerability was found in.
Corresponds to the JSON property affectedPackage
2627 2628 2629 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2627 def affected_package @affected_package end |
#affected_version ⇒ Google::Apis::OndemandscanningV1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property affectedVersion
2632 2633 2634 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2632 def affected_version @affected_version end |
#effective_severity ⇒ String
Output only. The distro or language system assigned severity for this
vulnerability when that is available and note provider assigned severity when
it is not available.
Corresponds to the JSON property effectiveSeverity
2639 2640 2641 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2639 def effective_severity @effective_severity end |
#file_location ⇒ Array<Google::Apis::OndemandscanningV1::GrafeasV1FileLocation>
The location at which this package was found.
Corresponds to the JSON property fileLocation
2644 2645 2646 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2644 def file_location @file_location end |
#fix_available ⇒ Boolean Also known as: fix_available?
Output only. Whether a fix is available for this package.
Corresponds to the JSON property fixAvailable
2649 2650 2651 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2649 def fix_available @fix_available end |
#fixed_cpe_uri ⇒ String
The CPE URI this vulnerability was
fixed in. It is possible for this to be different from the affected_cpe_uri.
Corresponds to the JSON property fixedCpeUri
2656 2657 2658 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2656 def fixed_cpe_uri @fixed_cpe_uri end |
#fixed_package ⇒ String
The package this vulnerability was fixed in. It is possible for this to be
different from the affected_package.
Corresponds to the JSON property fixedPackage
2662 2663 2664 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2662 def fixed_package @fixed_package end |
#fixed_version ⇒ Google::Apis::OndemandscanningV1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property fixedVersion
2667 2668 2669 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2667 def fixed_version @fixed_version end |
#package_type ⇒ String
The type of package (e.g. OS, MAVEN, GO).
Corresponds to the JSON property packageType
2672 2673 2674 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2672 def package_type @package_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2679 def update!(**args) @affected_cpe_uri = args[:affected_cpe_uri] if args.key?(:affected_cpe_uri) @affected_package = args[:affected_package] if args.key?(:affected_package) @affected_version = args[:affected_version] if args.key?(:affected_version) @effective_severity = args[:effective_severity] if args.key?(:effective_severity) @file_location = args[:file_location] if args.key?(:file_location) @fix_available = args[:fix_available] if args.key?(:fix_available) @fixed_cpe_uri = args[:fixed_cpe_uri] if args.key?(:fixed_cpe_uri) @fixed_package = args[:fixed_package] if args.key?(:fixed_package) @fixed_version = args[:fixed_version] if args.key?(:fixed_version) @package_type = args[:package_type] if args.key?(:package_type) end |