Class: Google::Apis::OndemandscanningV1::PackageOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::PackageOccurrence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Details on how a particular software package was installed on a system.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#cpe_uri ⇒ String
Output only.
-
#license ⇒ Google::Apis::OndemandscanningV1::License
License information.
-
#location ⇒ Array<Google::Apis::OndemandscanningV1::Location>
All of the places within the filesystem versions of this package have been found.
-
#name ⇒ String
Required.
-
#package_type ⇒ String
Output only.
-
#version ⇒ Google::Apis::OndemandscanningV1::Version
Version contains structured information about the version of a package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageOccurrence
constructor
A new instance of PackageOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageOccurrence
Returns a new instance of PackageOccurrence.
2917 2918 2919 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2917 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. The CPU architecture for which packages in this distribution
channel were built. Architecture will be blank for language packages.
Corresponds to the JSON property architecture
2881 2882 2883 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2881 def architecture @architecture end |
#cpe_uri ⇒ String
Output only. The cpe_uri in CPE format
denoting the package manager version distributing a package. The cpe_uri will
be blank for language packages.
Corresponds to the JSON property cpeUri
2888 2889 2890 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2888 def cpe_uri @cpe_uri end |
#license ⇒ Google::Apis::OndemandscanningV1::License
License information.
Corresponds to the JSON property license
2893 2894 2895 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2893 def license @license end |
#location ⇒ Array<Google::Apis::OndemandscanningV1::Location>
All of the places within the filesystem versions of this package have been
found.
Corresponds to the JSON property location
2899 2900 2901 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2899 def location @location end |
#name ⇒ String
Required. Output only. The name of the installed package.
Corresponds to the JSON property name
2904 2905 2906 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2904 def name @name end |
#package_type ⇒ String
Output only. The type of package; whether native or non native (e.g., ruby
gems, node.js packages, etc.).
Corresponds to the JSON property packageType
2910 2911 2912 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2910 def package_type @package_type end |
#version ⇒ Google::Apis::OndemandscanningV1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property version
2915 2916 2917 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2915 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2922 2923 2924 2925 2926 2927 2928 2929 2930 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2922 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @license = args[:license] if args.key?(:license) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @package_type = args[:package_type] if args.key?(:package_type) @version = args[:version] if args.key?(:version) end |