Class: Google::Apis::OndemandscanningV1::PackageOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Details on how a particular software package was installed on a system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageOccurrence

Returns a new instance of PackageOccurrence.



2863
2864
2865
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

Output only. The CPU architecture for which packages in this distribution channel were built. Architecture will be blank for language packages. Corresponds to the JSON property architecture

Returns:

  • (String)


2827
2828
2829
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2827

def architecture
  @architecture
end

#cpe_uriString

Output only. The cpe_uri in CPE format denoting the package manager version distributing a package. The cpe_uri will be blank for language packages. Corresponds to the JSON property cpeUri

Returns:

  • (String)


2834
2835
2836
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2834

def cpe_uri
  @cpe_uri
end

#licenseGoogle::Apis::OndemandscanningV1::License

License information. Corresponds to the JSON property license



2839
2840
2841
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2839

def license
  @license
end

#locationArray<Google::Apis::OndemandscanningV1::Location>

All of the places within the filesystem versions of this package have been found. Corresponds to the JSON property location



2845
2846
2847
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2845

def location
  @location
end

#nameString

Required. Output only. The name of the installed package. Corresponds to the JSON property name

Returns:

  • (String)


2850
2851
2852
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2850

def name
  @name
end

#package_typeString

Output only. The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.). Corresponds to the JSON property packageType

Returns:

  • (String)


2856
2857
2858
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2856

def package_type
  @package_type
end

#versionGoogle::Apis::OndemandscanningV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property version



2861
2862
2863
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2861

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2868
2869
2870
2871
2872
2873
2874
2875
2876
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2868

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @license = args[:license] if args.key?(:license)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @package_type = args[:package_type] if args.key?(:package_type)
  @version = args[:version] if args.key?(:version)
end