Class: Google::Apis::OndemandscanningV1::PackageOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Details on how a particular software package was installed on a system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageOccurrence

Returns a new instance of PackageOccurrence.



2855
2856
2857
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

Output only. The CPU architecture for which packages in this distribution channel were built. Architecture will be blank for language packages. Corresponds to the JSON property architecture

Returns:

  • (String)


2819
2820
2821
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2819

def architecture
  @architecture
end

#cpe_uriString

Output only. The cpe_uri in CPE format denoting the package manager version distributing a package. The cpe_uri will be blank for language packages. Corresponds to the JSON property cpeUri

Returns:

  • (String)


2826
2827
2828
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2826

def cpe_uri
  @cpe_uri
end

#licenseGoogle::Apis::OndemandscanningV1::License

License information. Corresponds to the JSON property license



2831
2832
2833
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2831

def license
  @license
end

#locationArray<Google::Apis::OndemandscanningV1::Location>

All of the places within the filesystem versions of this package have been found. Corresponds to the JSON property location



2837
2838
2839
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2837

def location
  @location
end

#nameString

Required. Output only. The name of the installed package. Corresponds to the JSON property name

Returns:

  • (String)


2842
2843
2844
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2842

def name
  @name
end

#package_typeString

Output only. The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.). Corresponds to the JSON property packageType

Returns:

  • (String)


2848
2849
2850
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2848

def package_type
  @package_type
end

#versionGoogle::Apis::OndemandscanningV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property version



2853
2854
2855
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2853

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2860
2861
2862
2863
2864
2865
2866
2867
2868
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2860

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @license = args[:license] if args.key?(:license)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @package_type = args[:package_type] if args.key?(:package_type)
  @version = args[:version] if args.key?(:version)
end