Class: Google::Apis::OndemandscanningV1::PackageVersion
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::PackageVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Instance Attribute Summary collapse
-
#licenses ⇒ Array<String>
The licenses associated with this package.
-
#name ⇒ String
Corresponds to the JSON property
name. -
#version ⇒ String
Corresponds to the JSON property
version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageVersion
constructor
A new instance of PackageVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageVersion
Returns a new instance of PackageVersion.
3005 3006 3007 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#licenses ⇒ Array<String>
The licenses associated with this package. Note that this has to go on the
PackageVersion level, because we can have cases with images with the same
source having different licences. E.g. in Alpine, musl and musl-utils both
have the same origin musl, but have different sets of licenses.
Corresponds to the JSON property licenses
2993 2994 2995 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2993 def licenses @licenses end |
#name ⇒ String
Corresponds to the JSON property name
2998 2999 3000 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2998 def name @name end |
#version ⇒ String
Corresponds to the JSON property version
3003 3004 3005 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3003 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3010 3011 3012 3013 3014 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3010 def update!(**args) @licenses = args[:licenses] if args.key?(:licenses) @name = args[:name] if args.key?(:name) @version = args[:version] if args.key?(:version) end |