Class: Google::Apis::OndemandscanningV1::PackageVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageVersion

Returns a new instance of PackageVersion.



2955
2956
2957
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2955

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#licensesArray<String>

The licenses associated with this package. Note that this has to go on the PackageVersion level, because we can have cases with images with the same source having different licences. E.g. in Alpine, musl and musl-utils both have the same origin musl, but have different sets of licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


2943
2944
2945
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2943

def licenses
  @licenses
end

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


2948
2949
2950
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2948

def name
  @name
end

#versionString

Corresponds to the JSON property version

Returns:

  • (String)


2953
2954
2955
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2953

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2960
2961
2962
2963
2964
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2960

def update!(**args)
  @licenses = args[:licenses] if args.key?(:licenses)
  @name = args[:name] if args.key?(:name)
  @version = args[:version] if args.key?(:version)
end