Class: Google::Apis::OndemandscanningV1::PackageVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageVersion

Returns a new instance of PackageVersion.



2901
2902
2903
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#licensesArray<String>

The licenses associated with this package. Note that this has to go on the PackageVersion level, because we can have cases with images with the same source having different licences. E.g. in Alpine, musl and musl-utils both have the same origin musl, but have different sets of licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


2889
2890
2891
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2889

def licenses
  @licenses
end

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


2894
2895
2896
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2894

def name
  @name
end

#versionString

Corresponds to the JSON property version

Returns:

  • (String)


2899
2900
2901
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2899

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2906
2907
2908
2909
2910
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2906

def update!(**args)
  @licenses = args[:licenses] if args.key?(:licenses)
  @name = args[:name] if args.key?(:name)
  @version = args[:version] if args.key?(:version)
end