Class: Google::Apis::OndemandscanningV1::PackageVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageVersion

Returns a new instance of PackageVersion.



2893
2894
2895
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#licensesArray<String>

The licenses associated with this package. Note that this has to go on the PackageVersion level, because we can have cases with images with the same source having different licences. E.g. in Alpine, musl and musl-utils both have the same origin musl, but have different sets of licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


2881
2882
2883
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2881

def licenses
  @licenses
end

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


2886
2887
2888
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2886

def name
  @name
end

#versionString

Corresponds to the JSON property version

Returns:

  • (String)


2891
2892
2893
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2891

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2898
2899
2900
2901
2902
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2898

def update!(**args)
  @licenses = args[:licenses] if args.key?(:licenses)
  @name = args[:name] if args.key?(:name)
  @version = args[:version] if args.key?(:version)
end