Class: Google::Apis::OndemandscanningV1::PackageVersion
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::PackageVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Instance Attribute Summary collapse
-
#licenses ⇒ Array<String>
The licenses associated with this package.
-
#name ⇒ String
Corresponds to the JSON property
name. -
#version ⇒ String
Corresponds to the JSON property
version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageVersion
constructor
A new instance of PackageVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageVersion
Returns a new instance of PackageVersion.
2775 2776 2777 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2775 def initialize(**args) update!(**args) end |
Instance Attribute Details
#licenses ⇒ Array<String>
The licenses associated with this package. Note that this has to go on the
PackageVersion level, because we can have cases with images with the same
source having different licences. E.g. in Alpine, musl and musl-utils both
have the same origin musl, but have different sets of licenses.
Corresponds to the JSON property licenses
2763 2764 2765 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2763 def licenses @licenses end |
#name ⇒ String
Corresponds to the JSON property name
2768 2769 2770 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2768 def name @name end |
#version ⇒ String
Corresponds to the JSON property version
2773 2774 2775 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2773 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2780 2781 2782 2783 2784 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 2780 def update!(**args) @licenses = args[:licenses] if args.key?(:licenses) @name = args[:name] if args.key?(:name) @version = args[:version] if args.key?(:version) end |