Class: Google::Apis::OndemandscanningV1::Recipe
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::Recipe
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe.
Instance Attribute Summary collapse
-
#arguments ⇒ Array<Hash<String,Object>>
Collection of all external inputs that influenced the build on top of recipe.
-
#defined_in_material ⇒ Fixnum
Index in materials containing the recipe steps that are not implied by recipe.
-
#entry_point ⇒ String
String identifying the entry point into the build.
-
#environment ⇒ Array<Hash<String,Object>>
Any other builder-controlled inputs necessary for correctly evaluating the recipe.
-
#type ⇒ String
URI indicating what type of recipe was performed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Recipe
constructor
A new instance of Recipe.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Recipe
Returns a new instance of Recipe.
3077 3078 3079 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Array<Hash<String,Object>>
Collection of all external inputs that influenced the build on top of recipe.
definedInMaterial and recipe.entryPoint. For example, if the recipe type were "
make", then this might be the flags passed to make aside from the target,
which is captured in recipe.entryPoint. Since the arguments field can greatly
vary in structure, depending on the builder and recipe type, this is of form "
Any".
Corresponds to the JSON property arguments
3043 3044 3045 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3043 def arguments @arguments end |
#defined_in_material ⇒ Fixnum
Index in materials containing the recipe steps that are not implied by recipe.
type. For example, if the recipe type were "make", then this would point to
the source containing the Makefile, not the make program itself. Set to -1 if
the recipe doesn't come from a material, as zero is default unset value for
int64.
Corresponds to the JSON property definedInMaterial
3052 3053 3054 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3052 def defined_in_material @defined_in_material end |
#entry_point ⇒ String
String identifying the entry point into the build. This is often a path to a
configuration file and/or a target label within that file. The syntax and
meaning are defined by recipe.type. For example, if the recipe type were "make"
, then this would reference the directory in which to run make as well as
which target to use.
Corresponds to the JSON property entryPoint
3061 3062 3063 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3061 def entry_point @entry_point end |
#environment ⇒ Array<Hash<String,Object>>
Any other builder-controlled inputs necessary for correctly evaluating the
recipe. Usually only needed for reproducing the build but not evaluated as
part of policy. Since the environment field can greatly vary in structure,
depending on the builder and recipe type, this is of form "Any".
Corresponds to the JSON property environment
3069 3070 3071 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3069 def environment @environment end |
#type ⇒ String
URI indicating what type of recipe was performed. It determines the meaning of
recipe.entryPoint, recipe.arguments, recipe.environment, and materials.
Corresponds to the JSON property type
3075 3076 3077 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3075 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3082 3083 3084 3085 3086 3087 3088 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3082 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @defined_in_material = args[:defined_in_material] if args.key?(:defined_in_material) @entry_point = args[:entry_point] if args.key?(:entry_point) @environment = args[:environment] if args.key?(:environment) @type = args[:type] if args.key?(:type) end |