Class: Google::Apis::OndemandscanningV1::Risk
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::Risk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Instance Attribute Summary collapse
-
#cisa_kev ⇒ Google::Apis::OndemandscanningV1::CisaKnownExploitedVulnerabilities
CISA maintains the authoritative source of vulnerabilities that have been exploited in the wild.
-
#epss ⇒ Google::Apis::OndemandscanningV1::ExploitPredictionScoringSystem
The Exploit Prediction Scoring System (EPSS) estimates the likelihood ( probability) that a software vulnerability will be exploited in the wild.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Risk
constructor
A new instance of Risk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Risk
Returns a new instance of Risk.
3059 3060 3061 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3059 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cisa_kev ⇒ Google::Apis::OndemandscanningV1::CisaKnownExploitedVulnerabilities
CISA maintains the authoritative source of vulnerabilities that have been
exploited in the wild.
Corresponds to the JSON property cisaKev
3051 3052 3053 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3051 def cisa_kev @cisa_kev end |
#epss ⇒ Google::Apis::OndemandscanningV1::ExploitPredictionScoringSystem
The Exploit Prediction Scoring System (EPSS) estimates the likelihood (
probability) that a software vulnerability will be exploited in the wild.
Corresponds to the JSON property epss
3057 3058 3059 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3057 def epss @epss end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3064 3065 3066 3067 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3064 def update!(**args) @cisa_kev = args[:cisa_kev] if args.key?(:cisa_kev) @epss = args[:epss] if args.key?(:epss) end |