Class: Google::Apis::OndemandscanningV1::SbomReferenceIntotoPredicate
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::SbomReferenceIntotoPredicate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
A predicate which describes the SBOM being referenced.
Instance Attribute Summary collapse
-
#digest ⇒ Hash<String,String>
A map of algorithm to digest of the contents of the SBOM.
-
#location ⇒ String
The location of the SBOM.
-
#mime_type ⇒ String
The mime type of the SBOM.
-
#referrer_id ⇒ String
The person or system referring this predicate to the consumer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SbomReferenceIntotoPredicate
constructor
A new instance of SbomReferenceIntotoPredicate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SbomReferenceIntotoPredicate
Returns a new instance of SbomReferenceIntotoPredicate.
3413 3414 3415 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3413 def initialize(**args) update!(**args) end |
Instance Attribute Details
#digest ⇒ Hash<String,String>
A map of algorithm to digest of the contents of the SBOM.
Corresponds to the JSON property digest
3396 3397 3398 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3396 def digest @digest end |
#location ⇒ String
The location of the SBOM.
Corresponds to the JSON property location
3401 3402 3403 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3401 def location @location end |
#mime_type ⇒ String
The mime type of the SBOM.
Corresponds to the JSON property mimeType
3406 3407 3408 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3406 def mime_type @mime_type end |
#referrer_id ⇒ String
The person or system referring this predicate to the consumer.
Corresponds to the JSON property referrerId
3411 3412 3413 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3411 def referrer_id @referrer_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3418 3419 3420 3421 3422 3423 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3418 def update!(**args) @digest = args[:digest] if args.key?(:digest) @location = args[:location] if args.key?(:location) @mime_type = args[:mime_type] if args.key?(:mime_type) @referrer_id = args[:referrer_id] if args.key?(:referrer_id) end |