Class: Google::Apis::OndemandscanningV1::SbomReferenceIntotoPredicate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

A predicate which describes the SBOM being referenced.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SbomReferenceIntotoPredicate

Returns a new instance of SbomReferenceIntotoPredicate.



3407
3408
3409
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

A map of algorithm to digest of the contents of the SBOM. Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


3390
3391
3392
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3390

def digest
  @digest
end

#locationString

The location of the SBOM. Corresponds to the JSON property location

Returns:

  • (String)


3395
3396
3397
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3395

def location
  @location
end

#mime_typeString

The mime type of the SBOM. Corresponds to the JSON property mimeType

Returns:

  • (String)


3400
3401
3402
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3400

def mime_type
  @mime_type
end

#referrer_idString

The person or system referring this predicate to the consumer. Corresponds to the JSON property referrerId

Returns:

  • (String)


3405
3406
3407
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3405

def referrer_id
  @referrer_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3412
3413
3414
3415
3416
3417
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3412

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @location = args[:location] if args.key?(:location)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @referrer_id = args[:referrer_id] if args.key?(:referrer_id)
end