Class: Google::Apis::OndemandscanningV1::SbomReferenceIntotoPredicate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

A predicate which describes the SBOM being referenced.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SbomReferenceIntotoPredicate

Returns a new instance of SbomReferenceIntotoPredicate.



3245
3246
3247
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

A map of algorithm to digest of the contents of the SBOM. Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


3228
3229
3230
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3228

def digest
  @digest
end

#locationString

The location of the SBOM. Corresponds to the JSON property location

Returns:

  • (String)


3233
3234
3235
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3233

def location
  @location
end

#mime_typeString

The mime type of the SBOM. Corresponds to the JSON property mimeType

Returns:

  • (String)


3238
3239
3240
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3238

def mime_type
  @mime_type
end

#referrer_idString

The person or system referring this predicate to the consumer. Corresponds to the JSON property referrerId

Returns:

  • (String)


3243
3244
3245
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3243

def referrer_id
  @referrer_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3250
3251
3252
3253
3254
3255
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3250

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @location = args[:location] if args.key?(:location)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @referrer_id = args[:referrer_id] if args.key?(:referrer_id)
end