Class: Google::Apis::OndemandscanningV1::SlsaMetadata
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::SlsaMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Other properties of the build.
Instance Attribute Summary collapse
-
#build_finished_on ⇒ String
The timestamp of when the build completed.
-
#build_invocation_id ⇒ String
Identifies the particular build invocation, which can be useful for finding associated logs or other ad-hoc analysis.
-
#build_started_on ⇒ String
The timestamp of when the build started.
-
#completeness ⇒ Google::Apis::OndemandscanningV1::SlsaCompleteness
Indicates that the builder claims certain fields in this message to be complete.
-
#reproducible ⇒ Boolean
(also: #reproducible?)
If true, the builder claims that running the recipe on materials will produce bit-for-bit identical output.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlsaMetadata
constructor
A new instance of SlsaMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlsaMetadata
Returns a new instance of SlsaMetadata.
3484 3485 3486 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3484 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build_finished_on ⇒ String
The timestamp of when the build completed.
Corresponds to the JSON property buildFinishedOn
3457 3458 3459 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3457 def build_finished_on @build_finished_on end |
#build_invocation_id ⇒ String
Identifies the particular build invocation, which can be useful for finding
associated logs or other ad-hoc analysis. The value SHOULD be globally unique,
per in-toto Provenance spec.
Corresponds to the JSON property buildInvocationId
3464 3465 3466 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3464 def build_invocation_id @build_invocation_id end |
#build_started_on ⇒ String
The timestamp of when the build started.
Corresponds to the JSON property buildStartedOn
3469 3470 3471 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3469 def build_started_on @build_started_on end |
#completeness ⇒ Google::Apis::OndemandscanningV1::SlsaCompleteness
Indicates that the builder claims certain fields in this message to be
complete.
Corresponds to the JSON property completeness
3475 3476 3477 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3475 def completeness @completeness end |
#reproducible ⇒ Boolean Also known as: reproducible?
If true, the builder claims that running the recipe on materials will produce
bit-for-bit identical output.
Corresponds to the JSON property reproducible
3481 3482 3483 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3481 def reproducible @reproducible end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3489 3490 3491 3492 3493 3494 3495 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3489 def update!(**args) @build_finished_on = args[:build_finished_on] if args.key?(:build_finished_on) @build_invocation_id = args[:build_invocation_id] if args.key?(:build_invocation_id) @build_started_on = args[:build_started_on] if args.key?(:build_started_on) @completeness = args[:completeness] if args.key?(:completeness) @reproducible = args[:reproducible] if args.key?(:reproducible) end |