Class: Google::Apis::OndemandscanningV1::SlsaProvenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenance

Returns a new instance of SlsaProvenance.



3738
3739
3740
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3738

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builderGoogle::Apis::OndemandscanningV1::SlsaBuilder

required Corresponds to the JSON property builder



3717
3718
3719
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3717

def builder
  @builder
end

#materialsArray<Google::Apis::OndemandscanningV1::Material>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials



3725
3726
3727
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3725

def materials
  @materials
end

#metadataGoogle::Apis::OndemandscanningV1::SlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



3730
3731
3732
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3730

def 
  @metadata
end

#recipeGoogle::Apis::OndemandscanningV1::SlsaRecipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



3736
3737
3738
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3736

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3743
3744
3745
3746
3747
3748
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3743

def update!(**args)
  @builder = args[:builder] if args.key?(:builder)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end