Class: Google::Apis::OndemandscanningV1::SlsaProvenance
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::SlsaProvenance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Instance Attribute Summary collapse
-
#builder ⇒ Google::Apis::OndemandscanningV1::SlsaBuilder
required Corresponds to the JSON property
builder. -
#materials ⇒ Array<Google::Apis::OndemandscanningV1::Material>
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
-
#metadata ⇒ Google::Apis::OndemandscanningV1::SlsaMetadata
Other properties of the build.
-
#recipe ⇒ Google::Apis::OndemandscanningV1::SlsaRecipe
Steps taken to build the artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlsaProvenance
constructor
A new instance of SlsaProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlsaProvenance
Returns a new instance of SlsaProvenance.
3634 3635 3636 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3634 def initialize(**args) update!(**args) end |
Instance Attribute Details
#builder ⇒ Google::Apis::OndemandscanningV1::SlsaBuilder
required
Corresponds to the JSON property builder
3613 3614 3615 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3613 def builder @builder end |
#materials ⇒ Array<Google::Apis::OndemandscanningV1::Material>
The collection of artifacts that influenced the build including sources,
dependencies, build tools, base images, and so on. This is considered to be
incomplete unless metadata.completeness.materials is true. Unset or null is
equivalent to empty.
Corresponds to the JSON property materials
3621 3622 3623 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3621 def materials @materials end |
#metadata ⇒ Google::Apis::OndemandscanningV1::SlsaMetadata
Other properties of the build.
Corresponds to the JSON property metadata
3626 3627 3628 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3626 def @metadata end |
#recipe ⇒ Google::Apis::OndemandscanningV1::SlsaRecipe
Steps taken to build the artifact. For a TaskRun, typically each container
corresponds to one step in the recipe.
Corresponds to the JSON property recipe
3632 3633 3634 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3632 def recipe @recipe end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3639 3640 3641 3642 3643 3644 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3639 def update!(**args) @builder = args[:builder] if args.key?(:builder) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) @recipe = args[:recipe] if args.key?(:recipe) end |