Class: Google::Apis::OndemandscanningV1::SlsaProvenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenance

Returns a new instance of SlsaProvenance.



3508
3509
3510
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3508

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builderGoogle::Apis::OndemandscanningV1::SlsaBuilder

required Corresponds to the JSON property builder



3487
3488
3489
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3487

def builder
  @builder
end

#materialsArray<Google::Apis::OndemandscanningV1::Material>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials



3495
3496
3497
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3495

def materials
  @materials
end

#metadataGoogle::Apis::OndemandscanningV1::SlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



3500
3501
3502
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3500

def 
  @metadata
end

#recipeGoogle::Apis::OndemandscanningV1::SlsaRecipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



3506
3507
3508
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3506

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3513
3514
3515
3516
3517
3518
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3513

def update!(**args)
  @builder = args[:builder] if args.key?(:builder)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end