Class: Google::Apis::OndemandscanningV1::SlsaProvenanceZeroTwo
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::SlsaProvenanceZeroTwo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
See full explanation of fields at slsa.dev/provenance/v0.2.
Instance Attribute Summary collapse
-
#build_config ⇒ Hash<String,Object>
Corresponds to the JSON property
buildConfig. -
#build_type ⇒ String
Corresponds to the JSON property
buildType. -
#builder ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder
Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.
-
#invocation ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation
Identifies the event that kicked off the build.
-
#materials ⇒ Array<Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial>
Corresponds to the JSON property
materials. -
#metadata ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
Other properties of the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlsaProvenanceZeroTwo
constructor
A new instance of SlsaProvenanceZeroTwo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlsaProvenanceZeroTwo
Returns a new instance of SlsaProvenanceZeroTwo.
3763 3764 3765 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build_config ⇒ Hash<String,Object>
Corresponds to the JSON property buildConfig
3735 3736 3737 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3735 def build_config @build_config end |
#build_type ⇒ String
Corresponds to the JSON property buildType
3740 3741 3742 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3740 def build_type @build_type end |
#builder ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder
Identifies the entity that executed the recipe, which is trusted to have
correctly performed the operation and populated this provenance.
Corresponds to the JSON property builder
3746 3747 3748 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3746 def builder @builder end |
#invocation ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation
Identifies the event that kicked off the build.
Corresponds to the JSON property invocation
3751 3752 3753 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3751 def invocation @invocation end |
#materials ⇒ Array<Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial>
Corresponds to the JSON property materials
3756 3757 3758 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3756 def materials @materials end |
#metadata ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
Other properties of the build.
Corresponds to the JSON property metadata
3761 3762 3763 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3761 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3768 3769 3770 3771 3772 3773 3774 3775 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3768 def update!(**args) @build_config = args[:build_config] if args.key?(:build_config) @build_type = args[:build_type] if args.key?(:build_type) @builder = args[:builder] if args.key?(:builder) @invocation = args[:invocation] if args.key?(:invocation) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) end |