Class: Google::Apis::OndemandscanningV1::SlsaProvenanceZeroTwo
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::SlsaProvenanceZeroTwo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
See full explanation of fields at slsa.dev/provenance/v0.2.
Instance Attribute Summary collapse
-
#build_config ⇒ Hash<String,Object>
Corresponds to the JSON property
buildConfig. -
#build_type ⇒ String
Corresponds to the JSON property
buildType. -
#builder ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder
Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.
-
#invocation ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation
Identifies the event that kicked off the build.
-
#materials ⇒ Array<Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial>
Corresponds to the JSON property
materials. -
#metadata ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
Other properties of the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlsaProvenanceZeroTwo
constructor
A new instance of SlsaProvenanceZeroTwo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlsaProvenanceZeroTwo
Returns a new instance of SlsaProvenanceZeroTwo.
3701 3702 3703 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3701 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build_config ⇒ Hash<String,Object>
Corresponds to the JSON property buildConfig
3673 3674 3675 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3673 def build_config @build_config end |
#build_type ⇒ String
Corresponds to the JSON property buildType
3678 3679 3680 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3678 def build_type @build_type end |
#builder ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder
Identifies the entity that executed the recipe, which is trusted to have
correctly performed the operation and populated this provenance.
Corresponds to the JSON property builder
3684 3685 3686 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3684 def builder @builder end |
#invocation ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation
Identifies the event that kicked off the build.
Corresponds to the JSON property invocation
3689 3690 3691 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3689 def invocation @invocation end |
#materials ⇒ Array<Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial>
Corresponds to the JSON property materials
3694 3695 3696 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3694 def materials @materials end |
#metadata ⇒ Google::Apis::OndemandscanningV1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
Other properties of the build.
Corresponds to the JSON property metadata
3699 3700 3701 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3699 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3706 3707 3708 3709 3710 3711 3712 3713 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3706 def update!(**args) @build_config = args[:build_config] if args.key?(:build_config) @build_type = args[:build_type] if args.key?(:build_type) @builder = args[:builder] if args.key?(:builder) @invocation = args[:invocation] if args.key?(:invocation) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) end |