Class: Google::Apis::OndemandscanningV1::SourceContext
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::SourceContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
A SourceContext is a reference to a tree of files. A SourceContext together with a path point to a unique revision of a single file or directory.
Instance Attribute Summary collapse
-
#cloud_repo ⇒ Google::Apis::OndemandscanningV1::CloudRepoSourceContext
A CloudRepoSourceContext denotes a particular revision in a Google Cloud Source Repo.
-
#gerrit ⇒ Google::Apis::OndemandscanningV1::GerritSourceContext
A SourceContext referring to a Gerrit project.
-
#git ⇒ Google::Apis::OndemandscanningV1::GitSourceContext
A GitSourceContext denotes a particular revision in a third party Git repository (e.g., GitHub).
-
#labels ⇒ Hash<String,String>
Labels with user defined metadata.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceContext
constructor
A new instance of SourceContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceContext
Returns a new instance of SourceContext.
3747 3748 3749 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_repo ⇒ Google::Apis::OndemandscanningV1::CloudRepoSourceContext
A CloudRepoSourceContext denotes a particular revision in a Google Cloud
Source Repo.
Corresponds to the JSON property cloudRepo
3729 3730 3731 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3729 def cloud_repo @cloud_repo end |
#gerrit ⇒ Google::Apis::OndemandscanningV1::GerritSourceContext
A SourceContext referring to a Gerrit project.
Corresponds to the JSON property gerrit
3734 3735 3736 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3734 def gerrit @gerrit end |
#git ⇒ Google::Apis::OndemandscanningV1::GitSourceContext
A GitSourceContext denotes a particular revision in a third party Git
repository (e.g., GitHub).
Corresponds to the JSON property git
3740 3741 3742 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3740 def git @git end |
#labels ⇒ Hash<String,String>
Labels with user defined metadata.
Corresponds to the JSON property labels
3745 3746 3747 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3745 def labels @labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3752 3753 3754 3755 3756 3757 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3752 def update!(**args) @cloud_repo = args[:cloud_repo] if args.key?(:cloud_repo) @gerrit = args[:gerrit] if args.key?(:gerrit) @git = args[:git] if args.key?(:git) @labels = args[:labels] if args.key?(:labels) end |