Class: Google::Apis::OndemandscanningV1::UpgradeDistribution
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::UpgradeDistribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities.
Instance Attribute Summary collapse
-
#classification ⇒ String
The operating system classification of this Upgrade, as specified by the upstream operating system upgrade feed.
-
#cpe_uri ⇒ String
Required - The specific operating system this metadata applies to.
-
#cve ⇒ Array<String>
The cve tied to this Upgrade.
-
#severity ⇒ String
The severity as specified by the upstream operating system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeDistribution
constructor
A new instance of UpgradeDistribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeDistribution
Returns a new instance of UpgradeDistribution.
4185 4186 4187 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#classification ⇒ String
The operating system classification of this Upgrade, as specified by the
upstream operating system upgrade feed. For Windows the classification is one
of the category_ids listed at https://docs.microsoft.com/en-us/previous-
versions/windows/desktop/ff357803(v=vs.85)
Corresponds to the JSON property classification
4167 4168 4169 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4167 def classification @classification end |
#cpe_uri ⇒ String
Required - The specific operating system this metadata applies to. See https://
cpe.mitre.org/specification/.
Corresponds to the JSON property cpeUri
4173 4174 4175 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4173 def cpe_uri @cpe_uri end |
#cve ⇒ Array<String>
The cve tied to this Upgrade.
Corresponds to the JSON property cve
4178 4179 4180 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4178 def cve @cve end |
#severity ⇒ String
The severity as specified by the upstream operating system.
Corresponds to the JSON property severity
4183 4184 4185 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4183 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4190 4191 4192 4193 4194 4195 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4190 def update!(**args) @classification = args[:classification] if args.key?(:classification) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @cve = args[:cve] if args.key?(:cve) @severity = args[:severity] if args.key?(:severity) end |