Class: Google::Apis::OndemandscanningV1::UpgradeDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeDistribution

Returns a new instance of UpgradeDistribution.



4023
4024
4025
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classificationString

The operating system classification of this Upgrade, as specified by the upstream operating system upgrade feed. For Windows the classification is one of the category_ids listed at https://docs.microsoft.com/en-us/previous- versions/windows/desktop/ff357803(v=vs.85) Corresponds to the JSON property classification

Returns:

  • (String)


4005
4006
4007
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4005

def classification
  @classification
end

#cpe_uriString

Required - The specific operating system this metadata applies to. See https:// cpe.mitre.org/specification/. Corresponds to the JSON property cpeUri

Returns:

  • (String)


4011
4012
4013
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4011

def cpe_uri
  @cpe_uri
end

#cveArray<String>

The cve tied to this Upgrade. Corresponds to the JSON property cve

Returns:

  • (Array<String>)


4016
4017
4018
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4016

def cve
  @cve
end

#severityString

The severity as specified by the upstream operating system. Corresponds to the JSON property severity

Returns:

  • (String)


4021
4022
4023
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4021

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4028
4029
4030
4031
4032
4033
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4028

def update!(**args)
  @classification = args[:classification] if args.key?(:classification)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @cve = args[:cve] if args.key?(:cve)
  @severity = args[:severity] if args.key?(:severity)
end