Class: Google::Apis::OndemandscanningV1::UpgradeOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::UpgradeOccurrence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability). For Windows, both distribution and windows_update contain information for the Windows update.
Instance Attribute Summary collapse
-
#distribution ⇒ Google::Apis::OndemandscanningV1::UpgradeDistribution
The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE).
-
#package ⇒ String
Required for non-Windows OS.
-
#parsed_version ⇒ Google::Apis::OndemandscanningV1::Version
Version contains structured information about the version of a package.
-
#windows_update ⇒ Google::Apis::OndemandscanningV1::WindowsUpdate
Windows Update represents the metadata about the update for the Windows operating system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeOccurrence
constructor
A new instance of UpgradeOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeOccurrence
Returns a new instance of UpgradeOccurrence.
4231 4232 4233 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4231 def initialize(**args) update!(**args) end |
Instance Attribute Details
#distribution ⇒ Google::Apis::OndemandscanningV1::UpgradeDistribution
The Upgrade Distribution represents metadata about the Upgrade for each
operating system (CPE). Some distributions have additional metadata around
updates, classifying them into various categories and severities.
Corresponds to the JSON property distribution
4211 4212 4213 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4211 def distribution @distribution end |
#package ⇒ String
Required for non-Windows OS. The package this Upgrade is for.
Corresponds to the JSON property package
4216 4217 4218 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4216 def package @package end |
#parsed_version ⇒ Google::Apis::OndemandscanningV1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property parsedVersion
4221 4222 4223 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4221 def parsed_version @parsed_version end |
#windows_update ⇒ Google::Apis::OndemandscanningV1::WindowsUpdate
Windows Update represents the metadata about the update for the Windows
operating system. The fields in this message come from the Windows Update API
documented at https://docs.microsoft.com/en-us/windows/win32/api/wuapi/nn-
wuapi-iupdate.
Corresponds to the JSON property windowsUpdate
4229 4230 4231 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4229 def windows_update @windows_update end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4236 4237 4238 4239 4240 4241 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4236 def update!(**args) @distribution = args[:distribution] if args.key?(:distribution) @package = args[:package] if args.key?(:package) @parsed_version = args[:parsed_version] if args.key?(:parsed_version) @windows_update = args[:windows_update] if args.key?(:windows_update) end |