Class: Google::Apis::OndemandscanningV1::UpgradeOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability). For Windows, both distribution and windows_update contain information for the Windows update.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeOccurrence

Returns a new instance of UpgradeOccurrence.



4001
4002
4003
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#distributionGoogle::Apis::OndemandscanningV1::UpgradeDistribution

The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities. Corresponds to the JSON property distribution



3981
3982
3983
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3981

def distribution
  @distribution
end

#packageString

Required for non-Windows OS. The package this Upgrade is for. Corresponds to the JSON property package

Returns:

  • (String)


3986
3987
3988
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3986

def package
  @package
end

#parsed_versionGoogle::Apis::OndemandscanningV1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property parsedVersion



3991
3992
3993
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3991

def parsed_version
  @parsed_version
end

#windows_updateGoogle::Apis::OndemandscanningV1::WindowsUpdate

Windows Update represents the metadata about the update for the Windows operating system. The fields in this message come from the Windows Update API documented at https://docs.microsoft.com/en-us/windows/win32/api/wuapi/nn- wuapi-iupdate. Corresponds to the JSON property windowsUpdate



3999
4000
4001
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3999

def windows_update
  @windows_update
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4006
4007
4008
4009
4010
4011
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4006

def update!(**args)
  @distribution = args[:distribution] if args.key?(:distribution)
  @package = args[:package] if args.key?(:package)
  @parsed_version = args[:parsed_version] if args.key?(:parsed_version)
  @windows_update = args[:windows_update] if args.key?(:windows_update)
end