Class: Google::Apis::OndemandscanningV1::Version

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Version contains structured information about the version of a package.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Version

Returns a new instance of Version.



4123
4124
4125
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4123

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#epochFixnum

Used to correct mistakes in the version numbering scheme. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


4089
4090
4091
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4089

def epoch
  @epoch
end

#full_nameString

Human readable version string. This string is of the form :- and is only set when kind is NORMAL. Corresponds to the JSON property fullName

Returns:

  • (String)


4095
4096
4097
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4095

def full_name
  @full_name
end

#inclusiveBoolean Also known as: inclusive?

Whether this version is specifying part of an inclusive range. Grafeas does not have the capability to specify version ranges; instead we have fields that specify start version and end versions. At times this is insufficient - we also need to specify whether the version is included in the range or is excluded from the range. This boolean is expected to be set to true when the version is included in a range. Corresponds to the JSON property inclusive

Returns:

  • (Boolean)


4105
4106
4107
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4105

def inclusive
  @inclusive
end

#kindString

Required. Distinguishes between sentinel MIN/MAX versions and normal versions. Corresponds to the JSON property kind

Returns:

  • (String)


4111
4112
4113
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4111

def kind
  @kind
end

#nameString

Required only when version kind is NORMAL. The main part of the version name. Corresponds to the JSON property name

Returns:

  • (String)


4116
4117
4118
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4116

def name
  @name
end

#revisionString

The iteration of the package build from the above version. Corresponds to the JSON property revision

Returns:

  • (String)


4121
4122
4123
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4121

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4128
4129
4130
4131
4132
4133
4134
4135
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4128

def update!(**args)
  @epoch = args[:epoch] if args.key?(:epoch)
  @full_name = args[:full_name] if args.key?(:full_name)
  @inclusive = args[:inclusive] if args.key?(:inclusive)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @revision = args[:revision] if args.key?(:revision)
end