Class: Google::Apis::OndemandscanningV1::Version
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1::Version
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb
Overview
Version contains structured information about the version of a package.
Instance Attribute Summary collapse
-
#epoch ⇒ Fixnum
Used to correct mistakes in the version numbering scheme.
-
#full_name ⇒ String
Human readable version string.
-
#inclusive ⇒ Boolean
(also: #inclusive?)
Whether this version is specifying part of an inclusive range.
-
#kind ⇒ String
Required.
-
#name ⇒ String
Required only when version kind is NORMAL.
-
#revision ⇒ String
The iteration of the package build from the above version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Version
constructor
A new instance of Version.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Version
Returns a new instance of Version.
4117 4118 4119 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4117 def initialize(**args) update!(**args) end |
Instance Attribute Details
#epoch ⇒ Fixnum
Used to correct mistakes in the version numbering scheme.
Corresponds to the JSON property epoch
4083 4084 4085 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4083 def epoch @epoch end |
#full_name ⇒ String
Human readable version string. This string is of the form :- and is only set
when kind is NORMAL.
Corresponds to the JSON property fullName
4089 4090 4091 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4089 def full_name @full_name end |
#inclusive ⇒ Boolean Also known as: inclusive?
Whether this version is specifying part of an inclusive range. Grafeas does
not have the capability to specify version ranges; instead we have fields that
specify start version and end versions. At times this is insufficient - we
also need to specify whether the version is included in the range or is
excluded from the range. This boolean is expected to be set to true when the
version is included in a range.
Corresponds to the JSON property inclusive
4099 4100 4101 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4099 def inclusive @inclusive end |
#kind ⇒ String
Required. Distinguishes between sentinel MIN/MAX versions and normal versions.
Corresponds to the JSON property kind
4105 4106 4107 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4105 def kind @kind end |
#name ⇒ String
Required only when version kind is NORMAL. The main part of the version name.
Corresponds to the JSON property name
4110 4111 4112 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4110 def name @name end |
#revision ⇒ String
The iteration of the package build from the above version.
Corresponds to the JSON property revision
4115 4116 4117 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4115 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4122 4123 4124 4125 4126 4127 4128 4129 |
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4122 def update!(**args) @epoch = args[:epoch] if args.key?(:epoch) @full_name = args[:full_name] if args.key?(:full_name) @inclusive = args[:inclusive] if args.key?(:inclusive) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @revision = args[:revision] if args.key?(:revision) end |