Class: Google::Apis::OndemandscanningV1::Version

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Version contains structured information about the version of a package.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Version

Returns a new instance of Version.



4063
4064
4065
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#epochFixnum

Used to correct mistakes in the version numbering scheme. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


4029
4030
4031
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4029

def epoch
  @epoch
end

#full_nameString

Human readable version string. This string is of the form :- and is only set when kind is NORMAL. Corresponds to the JSON property fullName

Returns:

  • (String)


4035
4036
4037
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4035

def full_name
  @full_name
end

#inclusiveBoolean Also known as: inclusive?

Whether this version is specifying part of an inclusive range. Grafeas does not have the capability to specify version ranges; instead we have fields that specify start version and end versions. At times this is insufficient - we also need to specify whether the version is included in the range or is excluded from the range. This boolean is expected to be set to true when the version is included in a range. Corresponds to the JSON property inclusive

Returns:

  • (Boolean)


4045
4046
4047
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4045

def inclusive
  @inclusive
end

#kindString

Required. Distinguishes between sentinel MIN/MAX versions and normal versions. Corresponds to the JSON property kind

Returns:

  • (String)


4051
4052
4053
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4051

def kind
  @kind
end

#nameString

Required only when version kind is NORMAL. The main part of the version name. Corresponds to the JSON property name

Returns:

  • (String)


4056
4057
4058
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4056

def name
  @name
end

#revisionString

The iteration of the package build from the above version. Corresponds to the JSON property revision

Returns:

  • (String)


4061
4062
4063
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4061

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4068
4069
4070
4071
4072
4073
4074
4075
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4068

def update!(**args)
  @epoch = args[:epoch] if args.key?(:epoch)
  @full_name = args[:full_name] if args.key?(:full_name)
  @inclusive = args[:inclusive] if args.key?(:inclusive)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @revision = args[:revision] if args.key?(:revision)
end