Class: Google::Apis::OndemandscanningV1::Version

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

Version contains structured information about the version of a package.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Version

Returns a new instance of Version.



3955
3956
3957
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3955

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#epochFixnum

Used to correct mistakes in the version numbering scheme. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


3921
3922
3923
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3921

def epoch
  @epoch
end

#full_nameString

Human readable version string. This string is of the form :- and is only set when kind is NORMAL. Corresponds to the JSON property fullName

Returns:

  • (String)


3927
3928
3929
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3927

def full_name
  @full_name
end

#inclusiveBoolean Also known as: inclusive?

Whether this version is specifying part of an inclusive range. Grafeas does not have the capability to specify version ranges; instead we have fields that specify start version and end versions. At times this is insufficient - we also need to specify whether the version is included in the range or is excluded from the range. This boolean is expected to be set to true when the version is included in a range. Corresponds to the JSON property inclusive

Returns:

  • (Boolean)


3937
3938
3939
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3937

def inclusive
  @inclusive
end

#kindString

Required. Distinguishes between sentinel MIN/MAX versions and normal versions. Corresponds to the JSON property kind

Returns:

  • (String)


3943
3944
3945
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3943

def kind
  @kind
end

#nameString

Required only when version kind is NORMAL. The main part of the version name. Corresponds to the JSON property name

Returns:

  • (String)


3948
3949
3950
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3948

def name
  @name
end

#revisionString

The iteration of the package build from the above version. Corresponds to the JSON property revision

Returns:

  • (String)


3953
3954
3955
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3953

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3960
3961
3962
3963
3964
3965
3966
3967
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3960

def update!(**args)
  @epoch = args[:epoch] if args.key?(:epoch)
  @full_name = args[:full_name] if args.key?(:full_name)
  @inclusive = args[:inclusive] if args.key?(:inclusive)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @revision = args[:revision] if args.key?(:revision)
end