Class: Google::Apis::OndemandscanningV1::VexAssessment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1/classes.rb,
lib/google/apis/ondemandscanning_v1/representations.rb,
lib/google/apis/ondemandscanning_v1/representations.rb

Overview

VexAssessment provides all publisher provided Vex information that is related to this vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VexAssessment

Returns a new instance of VexAssessment.



4004
4005
4006
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cveString

Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking number for the vulnerability. Deprecated: Use vulnerability_id instead to denote CVEs. Corresponds to the JSON property cve

Returns:

  • (String)


3962
3963
3964
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3962

def cve
  @cve
end

#impactsArray<String>

Contains information about the impact of this vulnerability, this will change with time. Corresponds to the JSON property impacts

Returns:

  • (Array<String>)


3968
3969
3970
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3968

def impacts
  @impacts
end

#justificationGoogle::Apis::OndemandscanningV1::Justification

Justification provides the justification when the state of the assessment if NOT_AFFECTED. Corresponds to the JSON property justification



3974
3975
3976
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3974

def justification
  @justification
end

#note_nameString

The VulnerabilityAssessment note from which this VexAssessment was generated. This will be of the form: projects/[PROJECT_ID]/notes/[NOTE_ID]. Corresponds to the JSON property noteName

Returns:

  • (String)


3980
3981
3982
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3980

def note_name
  @note_name
end

Holds a list of references associated with this vulnerability item and assessment. Corresponds to the JSON property relatedUris



3986
3987
3988
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3986

def related_uris
  @related_uris
end

#remediationsArray<Google::Apis::OndemandscanningV1::Remediation>

Specifies details on how to handle (and presumably, fix) a vulnerability. Corresponds to the JSON property remediations



3991
3992
3993
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3991

def remediations
  @remediations
end

#stateString

Provides the state of this Vulnerability assessment. Corresponds to the JSON property state

Returns:

  • (String)


3996
3997
3998
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 3996

def state
  @state
end

#vulnerability_idString

The vulnerability identifier for this Assessment. Will hold one of common identifiers e.g. CVE, GHSA etc. Corresponds to the JSON property vulnerabilityId

Returns:

  • (String)


4002
4003
4004
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4002

def vulnerability_id
  @vulnerability_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
# File 'lib/google/apis/ondemandscanning_v1/classes.rb', line 4009

def update!(**args)
  @cve = args[:cve] if args.key?(:cve)
  @impacts = args[:impacts] if args.key?(:impacts)
  @justification = args[:justification] if args.key?(:justification)
  @note_name = args[:note_name] if args.key?(:note_name)
  @related_uris = args[:related_uris] if args.key?(:related_uris)
  @remediations = args[:remediations] if args.key?(:remediations)
  @state = args[:state] if args.key?(:state)
  @vulnerability_id = args[:vulnerability_id] if args.key?(:vulnerability_id)
end